@@ -190,8 +190,7 @@ void cm_RevokeCallback(struct rx_call *callp, cm_cell_t * cellp, AFSFid *fidp)
              scp->fid.vnode == tfid.vnode &&
              scp->fid.unique == tfid.unique &&
              (cellp == NULL || scp->fid.cell == cellp->cellID) &&
-             scp->cbExpires > 0 && 
-             scp->cbServerp != NULL)
+             cm_HaveCallback(scp))
         {
             cm_HoldSCacheNoLock(scp);
             lock_ReleaseWrite(&cm_scacheLock);
@@ -357,8 +356,10 @@ SRXAFSCB_CallBack(struct rx_call *callp, AFSCBFids *fidsArrayp, AFSCBs *cbsArray
         port = rx_PortOf(peerp);
 
         tsp = cm_FindServerByIP(host, CM_SERVER_FILE);
-        if (tsp)
+        if (tsp) {
             cellp = tsp->cellp;
+            cm_PutServer(tsp);
+        }
 
         if (!cellp)
             osi_Log2(afsd_logp, "SRXAFSCB_CallBack from host 0x%x port %d",
@@ -1535,7 +1536,7 @@ int cm_HaveCallback(cm_scache_t *scp)
                 lock_ObtainWrite(&scp->rw);      // now get the lock back 
                 return 0;
             }
-            return 1;			// no change
+            return (cm_data.fakeDirVersion == scp->dataVersion);
         }
         return 0;
     }
@@ -1737,10 +1738,7 @@ long cm_GetCallback(cm_scache_t *scp, struct cm_user *userp,
     // cm_MergeStatus and mark that cm_fakeDirCallback is 2
     if (cm_freelanceEnabled) {
         if (scp->fid.cell==AFS_FAKE_ROOT_CELL_ID &&
-             scp->fid.volume==AFS_FAKE_ROOT_VOL_ID &&
-             scp->fid.unique==0x1 &&
-             scp->fid.vnode==0x1) {
-            
+            scp->fid.volume==AFS_FAKE_ROOT_VOL_ID) {
             // Start by indicating that we're in the process
             // of fetching the callback
             lock_ObtainMutex(&cm_Freelance_Lock);
@@ -1763,10 +1761,6 @@ long cm_GetCallback(cm_scache_t *scp, struct cm_user *userp,
 
             return 0;
         }
-
-        if (scp->fid.cell==AFS_FAKE_ROOT_CELL_ID && scp->fid.volume==AFS_FAKE_ROOT_VOL_ID) {
-            osi_Log0(afsd_logp,"cm_getcallback should NEVER EVER get here... ");
-        }
     }
 #endif /* AFS_FREELANCE_CLIENT */
 	
