@@ -22,7 +22,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vnodeops.c,v 1.126.2.38 2008/11/08 16:49:45 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vnodeops.c,v 1.126.2.54 2009/05/27 00:47:53 shadow Exp $");
 
 #include "afs/sysincludes.h"
 #include "afsincludes.h"
@@ -50,6 +50,10 @@ RCSID
 #define pageoff(pp) pp->offset
 #endif
 
+#ifndef MAX_ERRNO
+#define MAX_ERRNO 1000L
+#endif
+
 #if defined(AFS_LINUX26_ENV)
 #define LockPage(pp) lock_page(pp)
 #define UnlockPage(pp) unlock_page(pp)
@@ -58,7 +62,7 @@ extern struct backing_dev_info afs_backing_dev_info;
 
 extern struct vcache *afs_globalVp;
 extern int afs_notify_change(struct dentry *dp, struct iattr *iattrp);
-#if defined(AFS_LINUX26_ENV)
+#if defined(AFS_LINUX24_ENV)
 /* Some uses of BKL are perhaps not needed for bypass or memcache--
  * why don't we try it out? */
 extern struct afs_cacheOps afs_UfsCacheOps;
@@ -74,7 +78,7 @@ extern struct afs_cacheOps afs_UfsCacheOps;
 	if(afs_cacheType == &afs_UfsCacheOps)	       \
 	    unlock_kernel();			       \
     } while(0);
-#endif /* AFS_CACHE_BYPASS */
+#endif /* AFS_LINUX24_ENV */
 
 static ssize_t
 afs_linux_read(struct file *fp, char *buf, size_t count, loff_t * offp)
@@ -187,7 +191,6 @@ extern int BlobScan(struct dcache * afile, afs_int32 ablob);
 static int
 afs_linux_readdir(struct file *fp, void *dirbuf, filldir_t filldir)
 {
-    extern struct DirEntry *afs_dir_GetBlob();
     struct vcache *avc = VTOAFS(FILE_INODE(fp));
     struct vrequest treq;
     register struct dcache *tdc;
@@ -239,17 +242,17 @@ afs_linux_readdir(struct file *fp, void *dirbuf, filldir_t filldir)
      * 1. The cache data is being fetched by another process.
      * 2. The cache data is no longer valid
      */
-    while ((avc->states & CStatd)
+    while ((avc->f.states & CStatd)
 	   && (tdc->dflags & DFFetching)
-	   && hsame(avc->m.DataVersion, tdc->f.versionNo)) {
+	   && hsame(avc->f.m.DataVersion, tdc->f.versionNo)) {
 	ReleaseReadLock(&tdc->lock);
 	ReleaseSharedLock(&avc->lock);
 	afs_osi_Sleep(&tdc->validPos);
 	ObtainSharedLock(&avc->lock, 812);
 	ObtainReadLock(&tdc->lock);
     }
-    if (!(avc->states & CStatd)
-	|| !hsame(avc->m.DataVersion, tdc->f.versionNo)) {
+    if (!(avc->f.states & CStatd)
+	|| !hsame(avc->f.m.DataVersion, tdc->f.versionNo)) {
 	ReleaseReadLock(&tdc->lock);
 	ReleaseSharedLock(&avc->lock);
 	afs_PutDCache(tdc);
@@ -259,9 +262,9 @@ afs_linux_readdir(struct file *fp, void *dirbuf, filldir_t filldir)
     /* Set the readdir-in-progress flag, and downgrade the lock
      * to shared so others will be able to acquire a read lock.
      */
-    avc->states |= CReadDir;
+    avc->f.states |= CReadDir;
     avc->dcreaddir = tdc;
-    avc->readdir_pid = MyPidxx;
+    avc->readdir_pid = MyPidxx2Pid(MyPidxx);
     ConvertWToSLock(&avc->lock);
 
     /* Fill in until we get an error or we're done. This implementation
@@ -278,7 +281,7 @@ afs_linux_readdir(struct file *fp, void *dirbuf, filldir_t filldir)
 	if (!de)
 	    break;
 
-	ino = afs_calc_inum (avc->fid.Fid.Volume, ntohl(de->fid.vnode));
+	ino = afs_calc_inum (avc->f.fid.Fid.Volume, ntohl(de->fid.vnode));
 
 	if (de->name)
 	    len = strlen(de->name);
@@ -299,16 +302,16 @@ afs_linux_readdir(struct file *fp, void *dirbuf, filldir_t filldir)
 	    struct VenusFid afid;
 	    struct vcache *tvc;
 	    int vtype;
-	    afid.Cell = avc->fid.Cell;
-	    afid.Fid.Volume = avc->fid.Fid.Volume;
+	    afid.Cell = avc->f.fid.Cell;
+	    afid.Fid.Volume = avc->f.fid.Fid.Volume;
 	    afid.Fid.Vnode = ntohl(de->fid.vnode);
 	    afid.Fid.Unique = ntohl(de->fid.vunique);
-	    if ((avc->states & CForeign) == 0 && (ntohl(de->fid.vnode) & 1)) {
+	    if ((avc->f.states & CForeign) == 0 && (ntohl(de->fid.vnode) & 1)) {
 		type = DT_DIR;
 	    } else if ((tvc = afs_FindVCache(&afid, 0, 0))) {
 		if (tvc->mvstat) {
 		    type = DT_DIR;
-		} else if (((tvc->states) & (CStatd | CTruth))) {
+		} else if (((tvc->f.states) & (CStatd | CTruth))) {
 		    /* CTruth will be set if the object has
 		     *ever* been statd */
 		    vtype = vType(tvc);
@@ -349,7 +352,7 @@ afs_linux_readdir(struct file *fp, void *dirbuf, filldir_t filldir)
     ReleaseReadLock(&tdc->lock);
     afs_PutDCache(tdc);
     UpgradeSToWLock(&avc->lock, 813);
-    avc->states &= ~CReadDir;
+    avc->f.states &= ~CReadDir;
     avc->dcreaddir = 0;
     avc->readdir_pid = 0;
     ReleaseSharedLock(&avc->lock);
@@ -414,7 +417,7 @@ afs_linux_mmap(struct file *fp, struct vm_area_struct *vmap)
     code = generic_file_mmap(fp, vmap);
     AFS_GLOCK();
     if (!code)
-	vcp->states |= CMAPPED;
+	vcp->f.states |= CMAPPED;
 
 out:
     AFS_GUNLOCK();
@@ -501,13 +504,19 @@ afs_linux_lock(struct file *fp, int cmd, struct file_lock *flp)
     struct vcache *vcp = VTOAFS(FILE_INODE(fp));
     cred_t *credp = crref();
     struct AFS_FLOCK flock;
+#if defined(POSIX_TEST_LOCK_CONFLICT_ARG)
+    struct file_lock conflict;
+#elif defined(POSIX_TEST_LOCK_RETURNS_CONFLICT)
+    struct file_lock *conflict;
+#endif
+    
     /* Convert to a lock format afs_lockctl understands. */
     memset((char *)&flock, 0, sizeof(flock));
     flock.l_type = flp->fl_type;
     flock.l_pid = flp->fl_pid;
     flock.l_whence = 0;
     flock.l_start = flp->fl_start;
-    flock.l_len = flp->fl_end - flp->fl_start;
+    flock.l_len = flp->fl_end - flp->fl_start + 1;
 
     /* Safe because there are no large files, yet */
 #if defined(F_GETLK64) && (F_GETLK != F_GETLK64)
@@ -526,12 +535,12 @@ afs_linux_lock(struct file *fp, int cmd, struct file_lock *flp)
 #ifdef AFS_LINUX24_ENV
     if ((code == 0 || flp->fl_type == F_UNLCK) && 
 	(cmd == F_SETLK || cmd == F_SETLKW)) {
-#ifdef POSIX_LOCK_FILE_WAIT_ARG
+# ifdef POSIX_LOCK_FILE_WAIT_ARG
         code = posix_lock_file(fp, flp, 0);
-#else
+# else
         flp->fl_flags &=~ FL_SLEEP;
         code = posix_lock_file(fp, flp);
-#endif
+# endif
        if (code && flp->fl_type != F_UNLCK) {
            struct AFS_FLOCK flock2;
            flock2 = flock;
@@ -541,12 +550,40 @@ afs_linux_lock(struct file *fp, int cmd, struct file_lock *flp)
            AFS_GUNLOCK();
        }
     }
+    /* If lockctl says there are no conflicting locks, then also check with the
+     * kernel, as lockctl knows nothing about byte range locks
+     */
+    if (code == 0 && cmd == F_GETLK && flock.l_type == F_UNLCK) {
+# if defined(POSIX_TEST_LOCK_CONFLICT_ARG)
+        if (posix_test_lock(fp, flp, &conflict)) {
+            locks_copy_lock(flp, &conflict);
+            flp->fl_type = F_UNLCK;
+            crfree(credp);
+            return 0;
+        }
+# elif defined(POSIX_TEST_LOCK_RETURNS_CONFLICT)
+	if ((conflict = posix_test_lock(fp, flp))) {
+	    locks_copy_lock(flp, conflict);
+	    flp->fl_type = F_UNLCK;
+	    crfee(credp);
+	    return 0;
+	}
+# else
+        posix_test_lock(fp, flp);
+        /* If we found a lock in the kernel's structure, return it */
+        if (flp->fl_type != F_UNLCK) {
+            crfree(credp);
+            return 0;
+        }
+    }
+# endif
+    
 #endif
     /* Convert flock back to Linux's file_lock */
     flp->fl_type = flock.l_type;
     flp->fl_pid = flock.l_pid;
     flp->fl_start = flock.l_start;
-    flp->fl_end = flock.l_start + flock.l_len;
+    flp->fl_end = flock.l_start + flock.l_len - 1;
 
     crfree(credp);
     return -code;
@@ -663,20 +700,8 @@ afs_linux_flush(struct file *fp)
 				&treq,
 				AFS_SYNC | AFS_LASTSTORE);
 	} else {
-#if defined(AFS_DISCON_ENV)
-		if (!vcp->ddirty_flags ||
-		    (vcp->ddirty_flags == VDisconShadowed)) {
-
-		    ObtainWriteLock(&afs_DDirtyVCListLock, 710);
-		    AFS_DISCON_ADD_DIRTY(vcp);
-		    ReleaseWriteLock(&afs_DDirtyVCListLock);
-		}
-
-		/* Set disconnected write flag. */
-		vcp->ddirty_flags |= VDisconWriteOsiFlush;
-#endif
+		afs_DisconAddDirty(vcp, VDisconWriteOsiFlush, 1);
 	}
-
 	ConvertWToSLock(&vcp->lock);
     }
     code = afs_CheckCode(code, &treq, 54);
@@ -783,7 +808,7 @@ check_bad_parent(struct dentry *dp)
     struct vcache *vcp = VTOAFS(dp->d_inode), *avc = NULL;
     struct vcache *pvc = VTOAFS(dp->d_parent->d_inode);
 
-    if (vcp->mvid->Fid.Volume != pvc->fid.Fid.Volume) {	/* bad parent */
+    if (vcp->mvid->Fid.Volume != pvc->f.fid.Fid.Volume) {	/* bad parent */
 	credp = crref();
 
 	/* force a lookup, so vcp->mvid is fixed up */
@@ -820,7 +845,7 @@ afs_linux_revalidate(struct dentry *dp)
 
 #ifdef notyet
     /* Make this a fast path (no crref), since it's called so often. */
-    if (vcp->states & CStatd) {
+    if (vcp->f.states & CStatd) {
 
 	if (*dp->d_name.name != '/' && vcp->mvstat == 2)	/* root vnode */
 	    check_bad_parent(dp);	/* check and correct mvid */
@@ -898,7 +923,7 @@ afs_linux_dentry_revalidate(struct dentry *dp)
 	    goto good_dentry;
 
 	if (vcp->mvstat == 1) {         /* mount point */
-	    if (vcp->mvid && (vcp->states & CMValid)) {
+	    if (vcp->mvid && (vcp->f.states & CMValid)) {
 		int tryEvalOnly = 0;
 		int code = 0;
 		struct vrequest treq;
@@ -944,7 +969,7 @@ afs_linux_dentry_revalidate(struct dentry *dp)
 	 * isn't enough since the vnode may have been renamed.
 	 */
 
-	if (hgetlo(pvcp->m.DataVersion) > dp->d_time || !(vcp->states & CStatd)) {
+	if (hgetlo(pvcp->f.m.DataVersion) > dp->d_time || !(vcp->f.states & CStatd)) {
 
 	    credp = crref();
 	    afs_lookup(pvcp, dp->d_name.name, &tvc, credp);
@@ -955,7 +980,7 @@ afs_linux_dentry_revalidate(struct dentry *dp)
 		goto bad_dentry;
 
 	    vattr2inode(AFSTOV(vcp), &vattr);
-	    dp->d_time = hgetlo(pvcp->m.DataVersion);
+	    dp->d_time = hgetlo(pvcp->f.m.DataVersion);
 	}
 
 	/* should we always update the attributes at this point? */
@@ -964,7 +989,7 @@ afs_linux_dentry_revalidate(struct dentry *dp)
     } else {
 #ifdef notyet
 	pvcp = VTOAFS(dp->d_parent->d_inode);		/* dget_parent()? */
-	if (hgetlo(pvcp->m.DataVersion) > dp->d_time)
+	if (hgetlo(pvcp->f.m.DataVersion) > dp->d_time)
 	    goto bad_dentry;
 #endif
 
@@ -1012,7 +1037,9 @@ afs_dentry_iput(struct dentry *dp, struct inode *ip)
     struct vcache *vcp = VTOAFS(ip);
 
     AFS_GLOCK();
-    (void) afs_InactiveVCache(vcp, NULL);
+    if (!AFS_IS_DISCONNECTED || (vcp->f.states & CUnlinked)) {
+	(void) afs_InactiveVCache(vcp, NULL);
+    }
     AFS_GUNLOCK();
 #ifdef DCACHE_NFSFS_RENAMED
 #ifdef AFS_LINUX26_ENV
@@ -1030,7 +1057,7 @@ afs_dentry_iput(struct dentry *dp, struct inode *ip)
 static int
 afs_dentry_delete(struct dentry *dp)
 {
-    if (dp->d_inode && (VTOAFS(dp->d_inode)->states & CUnlinked))
+    if (dp->d_inode && (VTOAFS(dp->d_inode)->f.states & CUnlinked))
 	return 1;		/* bad inode? */
 
     return 0;
@@ -1086,7 +1113,7 @@ afs_linux_create(struct inode *dip, struct dentry *dp, int mode)
 	afs_fill_inode(ip, &vattr);
 	insert_inode_hash(ip);
 	dp->d_op = &afs_dentry_operations;
-	dp->d_time = hgetlo(VTOAFS(dip)->m.DataVersion);
+	dp->d_time = hgetlo(VTOAFS(dip)->f.m.DataVersion);
 	d_instantiate(dp, ip);
     }
     AFS_GUNLOCK();
@@ -1145,7 +1172,7 @@ afs_linux_lookup(struct inode *dip, struct dentry *dp)
 	    insert_inode_hash(ip);
     }
     dp->d_op = &afs_dentry_operations;
-    dp->d_time = hgetlo(VTOAFS(dip)->m.DataVersion);
+    dp->d_time = hgetlo(VTOAFS(dip)->f.m.DataVersion);
     AFS_GUNLOCK();
 
 #if defined(AFS_LINUX24_ENV)
@@ -1195,8 +1222,10 @@ afs_linux_lookup(struct inode *dip, struct dentry *dp)
     if (code == ENOENT)
 	return ERR_PTR(0);
 #endif
-    else
-	return ERR_PTR(-code);
+    else if ((code >= 0) && (code <= MAX_ERRNO))
+        return ERR_PTR(-code);
+    else 
+	return ERR_PTR(-EIO);
 #else
     if (code == ENOENT)
 	code = 0;
@@ -1237,10 +1266,9 @@ afs_linux_unlink(struct inode *dip, struct dentry *dp)
     maybe_lock_kernel();
 #endif
     if (VREFCOUNT(tvc) > 1 && tvc->opens > 0
-				&& !(tvc->states & CUnlinked)) {
+				&& !(tvc->f.states & CUnlinked)) {
 	struct dentry *__dp;
 	char *__name;
-	extern char *afs_newname();
 
 	__dp = NULL;
 	__name = NULL;
@@ -1268,7 +1296,7 @@ afs_linux_unlink(struct inode *dip, struct dentry *dp)
                 crfree(tvc->uncred);
             }
             tvc->uncred = credp;
-	    tvc->states |= CUnlinked;
+	    tvc->f.states |= CUnlinked;
 #ifdef DCACHE_NFSFS_RENAMED
 #ifdef AFS_LINUX26_ENV
 	    spin_lock(&dp->d_lock);
@@ -1284,7 +1312,7 @@ afs_linux_unlink(struct inode *dip, struct dentry *dp)
 	AFS_GUNLOCK();
 
 	if (!code) {
-	    __dp->d_time = hgetlo(VTOAFS(dip)->m.DataVersion);
+	    __dp->d_time = hgetlo(VTOAFS(dip)->f.m.DataVersion);
 	    d_move(dp, __dp);
 	}
 	dput(__dp);
@@ -1352,7 +1380,7 @@ afs_linux_mkdir(struct inode *dip, struct dentry *dp, int mode)
 	afs_fill_inode(ip, &vattr);
 
 	dp->d_op = &afs_dentry_operations;
-	dp->d_time = hgetlo(VTOAFS(dip)->m.DataVersion);
+	dp->d_time = hgetlo(VTOAFS(dip)->f.m.DataVersion);
 	d_instantiate(dp, ip);
     }
     AFS_GUNLOCK();
@@ -1537,7 +1565,10 @@ afs_linux_follow_link(struct dentry *dp, struct dentry *basep,
 
     if (code < 0) {
 	dput(basep);
-	res = ERR_PTR(code);
+	if (code < -MAX_ERRNO)
+	    res = ERR_PTR(-EIO);
+	else
+	    res = ERR_PTR(code);
     } else {
 	name[code] = '\0';
 	res = lookup_dentry(name, basep, follow);
@@ -1801,6 +1832,7 @@ afs_linux_readpage(struct file *fp, struct page *pp)
 	 maybe_lock_kernel();
 #endif
 	 AFS_GLOCK();
+	 AFS_DISCON_LOCK();
 	 afs_Trace4(afs_iclSetp, CM_TRACE_READPAGE, ICL_TYPE_POINTER, ip, ICL_TYPE_POINTER, pp, ICL_TYPE_INT32, cnt, ICL_TYPE_INT32, 99999);	/* not a possible code value */
 
 	 code = afs_rdwr(avc, auio, UIO_READ, 0, credp);
@@ -1808,6 +1840,7 @@ afs_linux_readpage(struct file *fp, struct page *pp)
 	 afs_Trace4(afs_iclSetp, CM_TRACE_READPAGE, ICL_TYPE_POINTER, ip,
 				ICL_TYPE_POINTER, pp, ICL_TYPE_INT32, cnt, ICL_TYPE_INT32,
 				code);
+	 AFS_DISCON_UNLOCK();
 	 AFS_GUNLOCK();
 #ifdef AFS_LINUX24_ENV
 	 maybe_unlock_kernel();
@@ -1896,9 +1929,9 @@ afs_linux_writepage_sync(struct inode *ip, struct page *pp,
 	       ICL_TYPE_POINTER, pp, ICL_TYPE_INT32, page_count(pp),
 	       ICL_TYPE_INT32, 99999);
 
-    ObtainReadLock(&vcp->lock);
-    if (vcp->states & CPageWrite) {
-	ReleaseReadLock(&vcp->lock);
+    ObtainWriteLock(&vcp->lock, 532);
+    if (vcp->f.states & CPageWrite) {
+	ReleaseWriteLock(&vcp->lock);
 	AFS_GUNLOCK();
 	maybe_unlock_kernel();
 	crfree(credp);
@@ -1914,25 +1947,28 @@ afs_linux_writepage_sync(struct inode *ip, struct page *pp,
 	return(0); 
 #endif
     }
-    ReleaseReadLock(&vcp->lock);
+    vcp->f.states |= CPageWrite;
+    ReleaseWriteLock(&vcp->lock);
 
     setup_uio(&tuio, &iovec, buffer, base, count, UIO_WRITE, AFS_UIOSYS);
 
     code = afs_write(vcp, &tuio, f_flags, credp, 0);
 
-    ip->i_size = vcp->m.Length;
-    ip->i_blocks = ((vcp->m.Length + 1023) >> 10) << 1;
+    i_size_write(ip, vcp->f.m.Length);
+    ip->i_blocks = ((vcp->f.m.Length + 1023) >> 10) << 1;
 
+    ObtainWriteLock(&vcp->lock, 533);
     if (!code) {
 	struct vrequest treq;
 
-	ObtainWriteLock(&vcp->lock, 533);
 	if (!afs_InitReq(&treq, credp))
 	    code = afs_DoPartialWrite(vcp, &treq);
-	ReleaseWriteLock(&vcp->lock);
     }
     code = code ? -code : count - tuio.uio_resid;
 
+    vcp->f.states &= ~CPageWrite;
+    ReleaseWriteLock(&vcp->lock);
+
     afs_Trace4(afs_iclSetp, CM_TRACE_UPDATEPAGE, ICL_TYPE_POINTER, vcp,
 	       ICL_TYPE_POINTER, pp, ICL_TYPE_INT32, page_count(pp),
 	       ICL_TYPE_INT32, code);
@@ -1974,20 +2010,25 @@ afs_linux_writepage(struct page *pp)
 #endif
 
     inode = (struct inode *)mapping->host;
-    end_index = inode->i_size >> PAGE_CACHE_SHIFT;
+    end_index = i_size_read(inode) >> PAGE_CACHE_SHIFT;
 
     /* easy case */
     if (pp->index < end_index)
 	goto do_it;
     /* things got complicated... */
-    offset = inode->i_size & (PAGE_CACHE_SIZE - 1);
+    offset = i_size_read(inode) & (PAGE_CACHE_SIZE - 1);
     /* OK, are we completely out? */
     if (pp->index >= end_index + 1 || !offset)
 	return -EIO;
   do_it:
     status = afs_linux_writepage_sync(inode, pp, 0, offset);
     SetPageUptodate(pp);
-    UnlockPage(pp);
+#if defined(WRITEPAGE_ACTIVATE)
+    if ( status != WRITEPAGE_ACTIVATE )
+#else
+    if ( status != AOP_WRITEPAGE_ACTIVATE )
+#endif
+	UnlockPage(pp);
     if (status == offset)
 	return 0;
     else
@@ -2014,6 +2055,7 @@ afs_linux_updatepage(struct file *fp, struct page *pp, unsigned long offset,
 
     credp = crref();
     AFS_GLOCK();
+    AFS_DISCON_LOCK();
     afs_Trace4(afs_iclSetp, CM_TRACE_UPDATEPAGE, ICL_TYPE_POINTER, vcp,
 	       ICL_TYPE_POINTER, pp, ICL_TYPE_INT32, page_count(pp),
 	       ICL_TYPE_INT32, 99999);
@@ -2023,14 +2065,14 @@ afs_linux_updatepage(struct file *fp, struct page *pp, unsigned long offset,
 
     code = afs_write(vcp, &tuio, fp->f_flags, credp, 0);
 
-    ip->i_size = vcp->m.Length;
-    ip->i_blocks = ((vcp->m.Length + 1023) >> 10) << 1;
+    i_size_write(ip, vcp->f.m.Length);
+    ip->i_blocks = ((vcp->f.m.Length + 1023) >> 10) << 1;
 
     if (!code) {
 	struct vrequest treq;
 
 	ObtainWriteLock(&vcp->lock, 533);
-	vcp->m.Date = osi_Time();   /* set modification time */
+	vcp->f.m.Date = osi_Time();   /* set modification time */
 	if (!afs_InitReq(&treq, credp))
 	    code = afs_DoPartialWrite(vcp, &treq);
 	ReleaseWriteLock(&vcp->lock);
@@ -2041,6 +2083,7 @@ afs_linux_updatepage(struct file *fp, struct page *pp, unsigned long offset,
 	       ICL_TYPE_POINTER, pp, ICL_TYPE_INT32, page_count(pp),
 	       ICL_TYPE_INT32, code);
 
+    AFS_DISCON_UNLOCK();
     AFS_GUNLOCK();
     crfree(credp);
 
@@ -2130,7 +2173,11 @@ afs_linux_write_begin(struct file *file, struct address_space *mapping,
 {
     struct page *page;
     pgoff_t index = pos >> PAGE_CACHE_SHIFT;
+#if defined(HAVE_GRAB_CACHE_PAGE_WRITE_BEGIN)
+    page = grab_cache_page_write_begin(mapping, index, flags);
+#else
     page = __grab_cache_page(mapping, index);
+#endif
     *pagep = page;
 
     return 0;
@@ -2268,7 +2315,9 @@ afs_fill_inode(struct inode *ip, struct vattr *vattr)
     if (vattr)
 	vattr2inode(ip, vattr);
 
+#if defined(AFS_LINUX26_ENV)
     ip->i_mapping->backing_dev_info = &afs_backing_dev_info;
+#endif
 /* Reset ops if symlink or directory. */
     if (S_ISREG(ip->i_mode)) {
 	ip->i_op = &afs_file_iops;
