@@ -11,7 +11,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/OBSD/osi_file.c,v 1.11.2.1 2006/11/09 23:30:54 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/OBSD/osi_file.c,v 1.11.2.2 2009/05/11 13:29:20 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #include "afs/afsincludes.h"	/* Afs-based standard headers */
@@ -26,7 +26,7 @@ extern struct mount *afs_cacheVfsp;
 
 
 void *
-osi_UFSOpen(afs_int32 ainode)
+osi_UFSOpen(afs_dcache_id_t *ainode)
 {
     struct osi_file *afile;
     struct vnode *vp;
@@ -38,7 +38,7 @@ osi_UFSOpen(afs_int32 ainode)
 	osi_Panic("UFSOpen called for non-UFS cache\n");
     afile = (struct osi_file *)osi_AllocSmallSpace(sizeof(struct osi_file));
     AFS_GUNLOCK();
-    code = VFS_VGET(cacheDev.mp, (ino_t) ainode, &vp);
+    code = VFS_VGET(cacheDev.mp, ainode->ufs, &vp);
     AFS_GLOCK();
     if (code == 0 && vp->v_type == VNON)
 	code = ENOENT;
@@ -55,7 +55,7 @@ osi_UFSOpen(afs_int32 ainode)
 #endif
     afile->offset = 0;
     afile->proc = NULL;
-    afile->inum = ainode;	/* for hint validity checking */
+    afile->inum = ainode->ufs;	/* for hint validity checking */
     return (void *)afile;
 }
 
