@@ -1,3 +1,4 @@
+
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
@@ -15,7 +16,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/UKERNEL/afs_usrops.c,v 1.30.6.9 2008/10/27 23:53:46 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/UKERNEL/afs_usrops.c,v 1.30.6.14 2009/05/11 13:29:20 shadow Exp $");
 
 
 #ifdef	UKERNEL
@@ -56,7 +57,7 @@ char afs_LclCellName[64];
 
 struct usr_vnode *afs_FileTable[MAX_OSI_FILES];
 int afs_FileFlags[MAX_OSI_FILES];
-int afs_FileOffsets[MAX_OSI_FILES];
+off_t afs_FileOffsets[MAX_OSI_FILES];
 
 #define MAX_CACHE_LOOPS 4
 
@@ -107,8 +108,8 @@ int usr_udpcksum = 0;
 
 usr_key_t afs_global_u_key;
 
-struct usr_proc *afs_global_procp;
-struct usr_ucred *afs_global_ucredp;
+struct usr_proc *afs_global_procp = NULL;
+struct usr_ucred *afs_global_ucredp = NULL;
 struct usr_sysent usr_sysent[200];
 
 #ifdef AFS_USR_OSF_ENV
@@ -254,21 +255,21 @@ usr_ioctl(void)
  * We do not support the inode related system calls
  */
 int
-afs_syscall_icreate(void)
+afs_syscall_icreate(long a, long b, long c, long d, long e, long f)
 {
     usr_assert(0);
     return 0;
 }
 
 int
-afs_syscall_iincdec(void)
+afs_syscall_iincdec(int dev, int inode, int inode_p1, int amount)
 {
     usr_assert(0);
     return 0;
 }
 
 int
-afs_syscall_iopen(void)
+afs_syscall_iopen(int dev, int inode, int usrmod)
 {
     usr_assert(0);
     return 0;
@@ -701,7 +702,7 @@ lookupname(char *fnamep, int segflg, int followlink,
  * open a file given its i-node number
  */
 void *
-osi_UFSOpen(afs_int32 ino)
+osi_UFSOpen(afs_dcache_id_t *ino)
 {
     int rc;
     struct osi_file *fp;
@@ -709,7 +710,7 @@ osi_UFSOpen(afs_int32 ino)
 
     AFS_ASSERT_GLOCK();
 
-    if (ino > n_osi_files) {
+    if (ino->ufs > n_osi_files) {
 	u.u_error = ENOENT;
 	return NULL;
     }
@@ -717,7 +718,7 @@ osi_UFSOpen(afs_int32 ino)
     AFS_GUNLOCK();
     fp = (struct osi_file *)afs_osi_Alloc(sizeof(struct osi_file));
     usr_assert(fp != NULL);
-    fp->fd = open(osi_file_table[ino - 1].name, O_RDWR | O_CREAT, 0);
+    fp->fd = open(osi_file_table[ino->ufs - 1].name, O_RDWR | O_CREAT, 0);
     if (fp->fd < 0) {
 	u.u_error = errno;
 	afs_osi_Free((char *)fp, sizeof(struct osi_file));
@@ -733,7 +734,7 @@ osi_UFSOpen(afs_int32 ino)
     }
     fp->size = st.st_size;
     fp->offset = 0;
-    fp->inum = ino;
+    fp->inum = ino->ufs;
     fp->vnode = (struct usr_vnode *)fp;
 
     AFS_GLOCK();
@@ -1044,13 +1045,13 @@ void
 osi_FlushPages(register struct vcache *avc, struct AFS_UCRED *credp)
 {
     ObtainSharedLock(&avc->lock, 555);
-    if ((hcmp((avc->m.DataVersion), (avc->mapDV)) <= 0)
+    if ((hcmp((avc->f.m.DataVersion), (avc->mapDV)) <= 0)
 	|| ((avc->execsOrWriters > 0) && afs_DirtyPages(avc))) {
 	ReleaseSharedLock(&avc->lock);
 	return;
     }
     UpgradeSToWLock(&avc->lock, 565);
-    hset(avc->mapDV, avc->m.DataVersion);
+    hset(avc->mapDV, avc->f.m.DataVersion);
     ReleaseWriteLock(&avc->lock);
     return;
 }
@@ -1058,8 +1059,8 @@ osi_FlushPages(register struct vcache *avc, struct AFS_UCRED *credp)
 void
 osi_FlushText_really(register struct vcache *vp)
 {
-    if (hcmp(vp->m.DataVersion, vp->flushDV) > 0) {
-	hset(vp->flushDV, vp->m.DataVersion);
+    if (hcmp(vp->f.m.DataVersion, vp->flushDV) > 0) {
+	hset(vp->flushDV, vp->f.m.DataVersion);
     }
     return;
 }
@@ -1314,8 +1315,13 @@ SweepAFSCache(int *vFilesFound)
     for (currp = readdir(cdirp); currp; currp = readdir(cdirp)) {
 	if (afsd_debug) {
 	    printf("%s: Current directory entry:\n", rn);
+#if defined(AFS_USR_DFBSD_ENV)
+	    printf("\tinode=%d, name='%s'\n", currp->d_ino,
+		   currp->d_name);
+#else
 	    printf("\tinode=%d, reclen=%d, name='%s'\n", currp->d_ino,
 		   currp->d_reclen, currp->d_name);
+#endif
 	}
 
 	/*
@@ -1561,7 +1567,7 @@ uafs_Init(char *rn, char *mountDirParam, char *confDirParam,
 	cacheStatEntries = cacheStatEntriesParam;
     }
     strcpy(cacheBaseDir, cacheBaseDirParam);
-    if (nDaemons != 0) {
+    if (nDaemonsParam != 0) {
 	nDaemons = nDaemonsParam;
     } else {
 	nDaemons = 3;
@@ -1846,7 +1852,11 @@ uafs_Init(char *rn, char *mountDirParam, char *confDirParam,
 			 (long)pathname_for_V[currVFile], 0, 0, 0);
 	}
     /*end for */
-#ifndef NETSCAPE_NSAPI
+/*#ifndef NETSCAPE_NSAPI*/
+#if 0
+/* this breaks solaris if the kernel-mode client has never been installed,
+ * and it doesn't seem to work now anyway, so just disable it */
+
     /*
      * Copy our tokens from the kernel to the user space client
      */
@@ -2062,6 +2072,7 @@ uafs_SetTokens(char *tbuffer, int tlen)
     iob.in_size = tlen;
     iob.out = &outbuf[0];
     iob.out_size = sizeof(outbuf);
+
     rc = call_syscall(AFSCALL_PIOCTL, 0, _VICEIOCTL(3), (long)&iob, 0, 0);
     if (rc != 0) {
 	errno = rc;
@@ -2691,6 +2702,7 @@ uafs_open_r(char *path, int flags, int mode)
 		errno = code;
 		return -1;
 	    }
+	    fileP = AFSTOV(vc);
 	} else {
 	    fileP = NULL;
 	    code = uafs_LookupName(nameP, dirP, &fileP, 1, 0);
@@ -2763,6 +2775,7 @@ uafs_open_r(char *path, int flags, int mode)
      */
     if ((flags & O_TRUNC) && (attrs.va_size != 0)) {
 	usr_vattr_null(&attrs);
+	attrs.va_mask = ATTR_SIZE;
 	attrs.va_size = 0;
 	code = afs_setattr(VTOAFS(fileP), &attrs, u.u_cred);
 	if (code != 0) {
@@ -2834,13 +2847,23 @@ uafs_write(int fd, char *buf, int len)
 {
     int retval;
     AFS_GLOCK();
-    retval = uafs_write_r(fd, buf, len);
+    retval = uafs_pwrite_r(fd, buf, len, afs_FileOffsets[fd]);
     AFS_GUNLOCK();
     return retval;
 }
 
 int
-uafs_write_r(int fd, char *buf, int len)
+uafs_pwrite(int fd, char *buf, int len, off_t offset)
+{
+    int retval;
+    AFS_GLOCK();
+    retval = uafs_pwrite_r(fd, buf, len, offset);
+    AFS_GUNLOCK();
+    return retval;
+}
+
+int
+uafs_pwrite_r(int fd, char *buf, int len, off_t offset)
 {
     int code;
     struct usr_uio uio;
@@ -2863,7 +2886,7 @@ uafs_write_r(int fd, char *buf, int len)
     iov[0].iov_len = len;
     uio.uio_iov = &iov[0];
     uio.uio_iovcnt = 1;
-    uio.uio_offset = afs_FileOffsets[fd];
+    uio.uio_offset = offset;
     uio.uio_segflg = 0;
     uio.uio_fmode = FWRITE;
     uio.uio_resid = len;
@@ -2890,13 +2913,23 @@ uafs_read(int fd, char *buf, int len)
 {
     int retval;
     AFS_GLOCK();
-    retval = uafs_read_r(fd, buf, len);
+    retval = uafs_pread_r(fd, buf, len, afs_FileOffsets[fd]);
     AFS_GUNLOCK();
     return retval;
 }
 
 int
-uafs_read_r(int fd, char *buf, int len)
+uafs_pread(int fd, char *buf, int len, off_t offset)
+{
+    int retval;
+    AFS_GLOCK();
+    retval = uafs_pread_r(fd, buf, len, offset);
+    AFS_GUNLOCK();
+    return retval;
+}
+
+int
+uafs_pread_r(int fd, char *buf, int len, off_t offset)
 {
     int code;
     struct usr_uio uio;
@@ -2920,7 +2953,7 @@ uafs_read_r(int fd, char *buf, int len)
     iov[0].iov_len = len;
     uio.uio_iov = &iov[0];
     uio.uio_iovcnt = 1;
-    uio.uio_offset = afs_FileOffsets[fd];
+    uio.uio_offset = offset;
     uio.uio_segflg = 0;
     uio.uio_fmode = FREAD;
     uio.uio_resid = len;
@@ -3104,6 +3137,7 @@ uafs_chmod_r(char *path, int mode)
 	return -1;
     }
     usr_vattr_null(&attrs);
+    attrs.va_mask = ATTR_MODE;
     attrs.va_mode = mode;
     code = afs_setattr(VTOAFS(vp), &attrs, u.u_cred);
     VN_RELE(vp);
@@ -3140,6 +3174,7 @@ uafs_fchmod_r(int fd, int mode)
 	return -1;
     }
     usr_vattr_null(&attrs);
+    attrs.va_mask = ATTR_MODE;
     attrs.va_mode = mode;
     code = afs_setattr(VTOAFS(vp), &attrs, u.u_cred);
     if (code != 0) {
@@ -3175,6 +3210,7 @@ uafs_truncate_r(char *path, int length)
 	return -1;
     }
     usr_vattr_null(&attrs);
+    attrs.va_mask = ATTR_SIZE;
     attrs.va_size = length;
     code = afs_setattr(VTOAFS(vp), &attrs, u.u_cred);
     VN_RELE(vp);
@@ -3211,6 +3247,7 @@ uafs_ftruncate_r(int fd, int length)
 	return -1;
     }
     usr_vattr_null(&attrs);
+    attrs.va_mask = ATTR_SIZE;
     attrs.va_size = length;
     code = afs_setattr(VTOAFS(vp), &attrs, u.u_cred);
     if (code != 0) {
