@@ -11,7 +11,7 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_buffer.c,v 1.22.4.3 2008/11/08 16:34:42 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/afs_buffer.c,v 1.22.4.6 2009/05/11 13:28:04 shadow Exp $");
 
 #include "afs/sysincludes.h"
 #include "afsincludes.h"
@@ -131,7 +131,7 @@ DInit(int abuffers)
 	/* Fill in each buffer with an empty indication. */
 	tb = &Buffers[i];
 	tb->fid = NULLIDX;
-	tb->inode = 0;
+	afs_reset_inode(&tb->inode);
 	tb->accesstime = 0;
 	tb->lockers = 0;
 #if defined(AFS_USEBUFFERS)
@@ -227,23 +227,19 @@ DRead(register struct dcache *adc, register int page)
     tb->lockers++;
     if (page * AFS_BUFFER_PAGESIZE >= adc->f.chunkBytes) {
 	tb->fid = NULLIDX;
-	tb->inode = 0;
+	afs_reset_inode(&tb->inode);
 	tb->lockers--;
 	MReleaseWriteLock(&tb->lock);
 	return NULL;
     }
-#if defined(LINUX_USE_FH)
-    tfile = afs_CFileOpen(&adc->f.fh, adc->f.fh_type);
-#else
-    tfile = afs_CFileOpen(adc->f.inode);
-#endif
+    tfile = afs_CFileOpen(&adc->f.inode);
     code =
 	afs_CFileRead(tfile, tb->page * AFS_BUFFER_PAGESIZE, tb->data,
 		      AFS_BUFFER_PAGESIZE);
     afs_CFileClose(tfile);
     if (code < AFS_BUFFER_PAGESIZE) {
 	tb->fid = NULLIDX;
-	tb->inode = 0;
+	afs_reset_inode(&tb->inode);
 	tb->lockers--;
 	MReleaseWriteLock(&tb->lock);
 	return NULL;
@@ -348,11 +344,7 @@ afs_newslot(struct dcache *adc, afs_int32 apage, register struct buffer *lp)
 
     if (lp->dirty) {
 	/* see DFlush for rationale for not getting and locking the dcache */
-#if defined(LINUX_USE_FH)
-        tfile = afs_CFileOpen(&lp->fh, lp->fh_type);
-#else
-        tfile = afs_CFileOpen(lp->inode);
-#endif
+        tfile = afs_CFileOpen(&lp->inode);
 	afs_CFileWrite(tfile, lp->page * AFS_BUFFER_PAGESIZE, lp->data,
 		       AFS_BUFFER_PAGESIZE);
 	lp->dirty = 0;
@@ -362,12 +354,7 @@ afs_newslot(struct dcache *adc, afs_int32 apage, register struct buffer *lp)
 
     /* Now fill in the header. */
     lp->fid = adc->index;
-#if defined(LINUX_USE_FH)
-    memcpy(&lp->fh, &adc->f.fh, sizeof(struct fid));
-    lp->fh_type = adc->f.fh_type;
-#else
-    lp->inode = adc->f.inode;
-#endif
+    afs_copy_inode(&lp->inode, &adc->f.inode);
     lp->page = apage;
     lp->accesstime = timecounter++;
     FixupBucket(lp);		/* move to the right hash bucket */
@@ -469,20 +456,55 @@ DZap(struct dcache *adc)
 	    if (tb->fid == adc->index) {
 		MObtainWriteLock(&tb->lock, 262);
 		tb->fid = NULLIDX;
-		tb->inode = 0;
+		afs_reset_inode(&tb->inode);
 		tb->dirty = 0;
 		MReleaseWriteLock(&tb->lock);
 	    }
     MReleaseReadLock(&afs_bufferLock);
 }
 
+static void
+DFlushBuffer(struct buffer *ab) {
+    struct osi_file *tfile;
+    
+    tfile = afs_CFileOpen(&ab->inode);
+    afs_CFileWrite(tfile, ab->page * AFS_BUFFER_PAGESIZE,
+		   ab->data, AFS_BUFFER_PAGESIZE);
+    ab->dirty = 0;	/* Clear the dirty flag */
+    afs_CFileClose(tfile);
+}
+
+void
+DFlushDCache(struct dcache *adc) 
+{
+    int i;
+    struct buffer *tb;
+
+    ObtainReadLock(&afs_bufferLock);
+
+    for (i = 0; i <= PHPAGEMASK; i++)
+        for (tb = phTable[pHash(adc->index, i)]; tb; tb = tb->hashNext)
+	    if (tb->fid == adc->index) {
+		ObtainWriteLock(&tb->lock, 701);
+		tb->lockers++;
+		ReleaseReadLock(&afs_bufferLock);
+		if (tb->dirty) {
+		    DFlushBuffer(tb);
+		}
+		tb->lockers--;
+		ReleaseWriteLock(&tb->lock);
+		ObtainReadLock(&afs_bufferLock);
+	    }
+
+    ReleaseReadLock(&afs_bufferLock);
+}
+
 void
 DFlush(void)
 {
     /* Flush all the modified buffers. */
     register int i;
     register struct buffer *tb;
-    struct osi_file *tfile;
 
     AFS_STATCNT(DFlush);
     tb = Buffers;
@@ -504,15 +526,7 @@ DFlush(void)
 		 * we cannot lock afs_xdcache). In addition, we cannot obtain
 		 * a dcache lock while holding the tb->lock of the same file
 		 * since that can deadlock with DRead/DNew */
-#if defined(LINUX_USE_FH)
-		tfile = afs_CFileOpen(&tb->fh, tb->fh_type);
-#else
-		tfile = afs_CFileOpen(tb->inode);
-#endif
-		afs_CFileWrite(tfile, tb->page * AFS_BUFFER_PAGESIZE,
-			       tb->data, AFS_BUFFER_PAGESIZE);
-		tb->dirty = 0;	/* Clear the dirty flag */
-		afs_CFileClose(tfile);
+		DFlushBuffer(tb);
 	    }
 	    tb->lockers--;
 	    MReleaseWriteLock(&tb->lock);
