@@ -11,19 +11,19 @@
 #include "afs/param.h"
 
 RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_memcache.c,v 1.15.2.1 2004/12/07 06:12:11 shadow Exp $");
+    ("$Header: /cvs/openafs/src/afs/afs_memcache.c,v 1.22.4.3 2009/05/11 13:28:04 shadow Exp $");
 
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
 #ifndef AFS_LINUX22_ENV
 #include "rpc/types.h"
 #endif
-#ifdef	AFS_ALPHA_ENV
+#ifdef	AFS_OSF_ENV
 #undef kmem_alloc
 #undef kmem_free
 #undef mem_alloc
 #undef mem_free
 #undef register
-#endif /* AFS_ALPHA_ENV */
+#endif /* AFS_OSF_ENV */
 #include "afsincludes.h"	/* Afs-based standard headers */
 #include "afs/afs_stats.h"	/* statistics */
 
@@ -89,23 +89,17 @@ afs_MemCacheClose(struct osi_file *file)
     return 0;
 }
 
-#if defined(AFS_SUN57_64BIT_ENV) || defined(AFS_SGI62_ENV)
 void *
-afs_MemCacheOpen(ino_t blkno)
-#else
-void *
-afs_MemCacheOpen(afs_int32 blkno)
-#endif
+afs_MemCacheOpen(afs_dcache_id_t *ainode)
 {
     struct memCacheEntry *mep;
 
-    if (blkno < 0 || blkno > memMaxBlkNumber) {
+    if (ainode->mem < 0 || ainode->mem > memMaxBlkNumber) {
 	osi_Panic("afs_MemCacheOpen: invalid block #");
     }
-    mep = (memCache + blkno);
-    afs_Trace4(afs_iclSetp, CM_TRACE_MEMOPEN, ICL_TYPE_INT32, blkno,
-	       ICL_TYPE_POINTER, mep, ICL_TYPE_POINTER, mep->data,
-	       ICL_TYPE_STRING, mep->data);
+    mep = (memCache + ainode->mem);
+    afs_Trace3(afs_iclSetp, CM_TRACE_MEMOPEN, ICL_TYPE_INT32, ainode->mem,
+	       ICL_TYPE_POINTER, mep, ICL_TYPE_POINTER, mep ? mep->data : 0);
     return (void *)mep;
 }
 
@@ -177,17 +171,17 @@ afs_MemReadvBlk(register struct memCacheEntry *mceP, int offset,
 }
 
 int
-afs_MemReadUIO(ino_t blkno, struct uio *uioP)
+afs_MemReadUIO(afs_dcache_id_t *ainode, struct uio *uioP)
 {
     register struct memCacheEntry *mceP =
-	(struct memCacheEntry *)afs_MemCacheOpen(blkno);
-    int length = mceP->size - uioP->uio_offset;
+	(struct memCacheEntry *)afs_MemCacheOpen(ainode);
+    int length = mceP->size - AFS_UIO_OFFSET(uioP);
     afs_int32 code;
 
     AFS_STATCNT(afs_MemReadUIO);
     MObtainReadLock(&mceP->afs_memLock);
-    length = (length < uioP->uio_resid) ? length : uioP->uio_resid;
-    AFS_UIOMOVE(mceP->data + uioP->uio_offset, length, UIO_READ, uioP, code);
+    length = (length < AFS_UIO_RESID(uioP)) ? length : AFS_UIO_RESID(uioP);
+    AFS_UIOMOVE(mceP->data + AFS_UIO_OFFSET(uioP), length, UIO_READ, uioP, code);
     MReleaseReadLock(&mceP->afs_memLock);
     return code;
 }
@@ -248,6 +242,13 @@ afs_MemWritevBlk(register struct memCacheEntry *mceP, int offset,
 	char *oldData = mceP->data;
 
 	mceP->data = afs_osi_Alloc(size + offset);
+	if (mceP->data == NULL) {	/* no available memory */
+	    mceP->data = oldData;	/* revert back change that was made */
+	    MReleaseWriteLock(&mceP->afs_memLock);
+	    afs_warn("afs: afs_MemWriteBlk mem alloc failure (%d bytes)\n",
+		     size + offset);
+	    return -ENOMEM;
+	}
 
 	/* may overlap, but this is OK */
 	AFS_GUNLOCK();
@@ -274,33 +275,40 @@ afs_MemWritevBlk(register struct memCacheEntry *mceP, int offset,
 }
 
 int
-afs_MemWriteUIO(ino_t blkno, struct uio *uioP)
+afs_MemWriteUIO(afs_dcache_id_t *ainode, struct uio *uioP)
 {
     register struct memCacheEntry *mceP =
-	(struct memCacheEntry *)afs_MemCacheOpen(blkno);
+	(struct memCacheEntry *)afs_MemCacheOpen(ainode);
     afs_int32 code;
 
     AFS_STATCNT(afs_MemWriteUIO);
     MObtainWriteLock(&mceP->afs_memLock, 312);
-    if (uioP->uio_resid + uioP->uio_offset > mceP->dataSize) {
+    if (AFS_UIO_RESID(uioP) + AFS_UIO_OFFSET(uioP) > mceP->dataSize) {
 	char *oldData = mceP->data;
 
-	mceP->data = afs_osi_Alloc(uioP->uio_resid + uioP->uio_offset);
+	mceP->data = afs_osi_Alloc(AFS_UIO_RESID(uioP) + AFS_UIO_OFFSET(uioP));
+	if (mceP->data == NULL) {	/* no available memory */
+	    mceP->data = oldData;	/* revert back change that was made */
+	    MReleaseWriteLock(&mceP->afs_memLock);
+	    afs_warn("afs: afs_MemWriteBlk mem alloc failure (%d bytes)\n",
+		     AFS_UIO_RESID(uioP) + AFS_UIO_OFFSET(uioP));
+	    return -ENOMEM;
+	}
 
 	AFS_GUNLOCK();
 	memcpy(mceP->data, oldData, mceP->size);
 	AFS_GLOCK();
 
 	afs_osi_Free(oldData, mceP->dataSize);
-	mceP->dataSize = uioP->uio_resid + uioP->uio_offset;
+	mceP->dataSize = AFS_UIO_RESID(uioP) + AFS_UIO_OFFSET(uioP);
     }
-    if (mceP->size < uioP->uio_offset)
+    if (mceP->size < AFS_UIO_OFFSET(uioP))
 	memset(mceP->data + mceP->size, 0,
-	       (int)(uioP->uio_offset - mceP->size));
-    AFS_UIOMOVE(mceP->data + uioP->uio_offset, uioP->uio_resid, UIO_WRITE,
+	       (int)(AFS_UIO_OFFSET(uioP) - mceP->size));
+    AFS_UIOMOVE(mceP->data + AFS_UIO_OFFSET(uioP), AFS_UIO_RESID(uioP), UIO_WRITE,
 		uioP, code);
-    if (uioP->uio_offset > mceP->size)
-	mceP->size = uioP->uio_offset;
+    if (AFS_UIO_OFFSET(uioP) > mceP->size)
+	mceP->size = AFS_UIO_OFFSET(uioP);
 
     MReleaseWriteLock(&mceP->afs_memLock);
     return code;
@@ -315,9 +323,17 @@ afs_MemCacheTruncate(register struct osi_file *fP, int size)
     MObtainWriteLock(&mceP->afs_memLock, 313);
     /* old directory entry; g.c. */
     if (size == 0 && mceP->dataSize > memCacheBlkSize) {
-	afs_osi_Free(mceP->data, mceP->dataSize);
+	char *oldData = mceP->data;
 	mceP->data = afs_osi_Alloc(memCacheBlkSize);
-	mceP->dataSize = memCacheBlkSize;
+	if (mceP->data == NULL) {	/* no available memory */
+	    mceP->data = oldData;
+	    MReleaseWriteLock(&mceP->afs_memLock);
+	    afs_warn("afs: afs_MemWriteBlk mem alloc failure (%d bytes)\n",
+		     memCacheBlkSize);
+	} else {
+	    afs_osi_Free(oldData, mceP->dataSize);
+	    mceP->dataSize = memCacheBlkSize;
+	}
     }
 
     if (size < mceP->size)
@@ -368,7 +384,7 @@ afs_MemCacheStoreProc(register struct rx_call *acall,
     /* for now, only do 'continue from close' code if file fits in one
      * chunk.  Could clearly do better: if only one modified chunk
      * then can still do this.  can do this on *last* modified chunk */
-    tlen = avc->m.Length - 1;	/* byte position of last byte we'll store */
+    tlen = avc->f.m.Length - 1;	/* byte position of last byte we'll store */
     if (shouldWake) {
 	if (AFS_CHUNK(tlen) != 0)
 	    *shouldWake = 0;
@@ -383,8 +399,9 @@ afs_MemCacheStoreProc(register struct rx_call *acall,
 	code = rx_WritevAlloc(acall, tiov, &tnio, RX_MAXIOVECS, tlen);
 	RX_AFS_GLOCK();
 	if (code <= 0) {
+	    code = rx_Error(acall);
 	    osi_FreeSmallSpace(tiov);
-	    return -33;
+	    return code ? code : -33;
 	}
 	tlen = code;
 	code = afs_MemReadvBlk(mceP, offset, tiov, tnio, tlen);
@@ -399,8 +416,9 @@ afs_MemCacheStoreProc(register struct rx_call *acall,
 	(*abytesXferredP) += code;
 #endif /* AFS_NOSTATS */
 	if (code != tlen) {
+	    code = rx_Error(acall);
 	    osi_FreeSmallSpace(tiov);
-	    return -33;
+	    return code ? code : -33;
 	}
 	offset += tlen;
 	alen -= tlen;
@@ -471,7 +489,7 @@ afs_MemCacheFetchProc(register struct rx_call *acall,
 	 * We do not do this for AFS file servers because they sometimes
 	 * return large negative numbers as the transfer size.
 	 */
-	if (avc->states & CForeign) {
+	if (avc->f.states & CForeign) {
 	    moredata = length & 0x80000000;
 	    length &= ~0x80000000;
 	} else {
