@@ -1,5 +1,5 @@
 /* 
- * $Id: aklog_main.c,v 1.12.2.17 2008/10/29 19:43:53 shadow Exp $
+ * $Id: aklog_main.c,v 1.12.2.20 2009/03/15 18:02:41 shadow Exp $
  *
  * Copyright 1990,1991 by the Massachusetts Institute of Technology
  * For distribution and copying rights, see the file "mit-copyright.h"
@@ -36,7 +36,7 @@
 
 #include <afsconfig.h>
 RCSID
-     ("$Header: /cvs/openafs/src/aklog/aklog_main.c,v 1.12.2.17 2008/10/29 19:43:53 shadow Exp $");
+     ("$Header: /cvs/openafs/src/aklog/aklog_main.c,v 1.12.2.20 2009/03/15 18:02:41 shadow Exp $");
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
@@ -637,25 +637,40 @@ static int auth_to_cell(krb5_context context, char *cell, char *realm)
 
 	if (! do524) {
 	    char *p;
+	    char k4name[ANAME_SZ], k4inst[INST_SZ], k4realm[REALM_SZ];
 	    int len;
 
 	    if (dflag)
 	    	printf("Using Kerberos V5 ticket natively\n");
 
+#ifndef HAVE_NO_KRB5_524
+	    status = krb5_524_conv_principal (context, v5cred->client, &k4name, &k4inst, &k4realm);
+	    if (status) {
+		afs_com_err(progname, status, "while converting principal "
+			"to Kerberos V4 format");
+		return(AKLOG_KERBEROS);
+	    }
+	    strcpy (username, k4name);
+	    if (k4inst[0]) {
+		strcat (username, ".");
+		strcat (username, k4inst);
+	    }
+#else
 	    len = min(get_princ_len(context, v5cred->client, 0),
-	    	      second_comp(context, v5cred->client) ?
-					MAXKTCNAMELEN - 2 : MAXKTCNAMELEN - 1);
+		      second_comp(context, v5cred->client) ?
+		      MAXKTCNAMELEN - 2 : MAXKTCNAMELEN - 1);
 	    strncpy(username, get_princ_str(context, v5cred->client, 0), len);
 	    username[len] = '\0';
-
+	    
 	    if (second_comp(context, v5cred->client)) {
-	    	strcat(username, ".");
+		strcat(username, ".");
 		p = username + strlen(username);
 		len = min(get_princ_len(context, v5cred->client, 1),
 			  MAXKTCNAMELEN - strlen(username) - 1);
 		strncpy(p, get_princ_str(context, v5cred->client, 1), len);
 		p[len] = '\0';
 	    }
+#endif
 
 	    memset(&atoken, 0, sizeof(atoken));
 	    atoken.kvno = RXKAD_TKT_TYPE_KERBEROS_V5;
