@@ -11,11 +11,18 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/audit/audit.c,v 1.8.2.8 2006/02/13 17:57:26 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/audit/audit.c,v 1.20.2.9 2009/03/16 01:38:17 shadow Exp $");
 
 #include <fcntl.h>
 #include <stdarg.h>
 #include <string.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#ifndef AFS_NT40_ENV
+#include <unistd.h>
+#else
+#include <io.h>
+#endif
 #ifdef AFS_AIX32_ENV
 #include <sys/audit.h>
 #else
@@ -37,6 +44,16 @@ RCSID
 #endif
 #include <afs/afsutil.h>
 
+/* C99 requires va_copy.  Older versions of GCC provide __va_copy.  Per t
+   Autoconf manual, memcpy is a generally portable fallback. */          
+#ifndef va_copy              
+# ifdef __va_copy
+#  define va_copy(d, s)         __va_copy((d), (s))             
+# else
+#  define va_copy(d, s)         memcpy(&(d), &(s), sizeof(va_list)) 
+# endif
+#endif      
+
 char *bufferPtr;
 int bufferLen;
 int osi_audit_all = (-1);	/* Not determined yet */
@@ -44,8 +61,9 @@ int osi_echo_trail = (-1);
 
 FILE *auditout = NULL;
 
-int osi_audit_check();
+int osi_audit_check(void);
 
+#ifdef AFS_AIX32_ENV
 static void
 audmakebuf(char *audEvent, va_list vaList)
 {
@@ -56,7 +74,6 @@ audmakebuf(char *audEvent, va_list vaList)
     int vaInt;
     afs_int32 vaLong;
     char *vaStr;
-    va_list vaLst;
     struct AFSFid *vaFid;
 
     vaEntry = va_arg(vaList, int);
@@ -87,10 +104,6 @@ audmakebuf(char *audEvent, va_list vaList)
 	    *(afs_int32 *) bufferPtr = vaLong;
 	    bufferPtr += sizeof(vaLong);
 	    break;
-	case AUD_LST:		/* Ptr to another list */
-	    vaLst = va_arg(vaList, va_list);
-	    audmakebuf(audEvent, vaLst);
-	    break;
 	case AUD_FID:		/* AFSFid - contains 3 entries */
 	    vaFid = (struct AFSFid *)va_arg(vaList, struct AFSFid *);
 	    if (vaFid) {
@@ -135,15 +148,16 @@ audmakebuf(char *audEvent, va_list vaList)
 	vaEntry = va_arg(vaList, int);
     }				/* end while */
 }
+#endif
 
 static void
-printbuf(FILE *out, int rec, char *audEvent, afs_int32 errCode, va_list vaList)
+printbuf(FILE *out, int rec, char *audEvent, char *afsName, afs_int32 hostId, 
+	 afs_int32 errCode, va_list vaList)
 {
     int vaEntry;
     int vaInt;
     afs_int32 vaLong;
     char *vaStr;
-    va_list vaLst;
     struct AFSFid *vaFid;
     struct AFSCBFids *vaFids;
     int num = LogThreadNum();
@@ -164,8 +178,12 @@ printbuf(FILE *out, int rec, char *audEvent, afs_int32 errCode, va_list vaList)
 	    fprintf(out, "[%d] ", num);
     }
     
-    if (strcmp(audEvent, "VALST") != 0)
-	fprintf(out,  "EVENT %s CODE %d ", audEvent, errCode);
+    fprintf(out,  "EVENT %s CODE %d ", audEvent, errCode);
+
+    if (afsName) {
+	hostAddr.s_addr = hostId;
+	fprintf(out,  "NAME %s HOST %s ", afsName, inet_ntoa(hostAddr));
+    }
 
     vaEntry = va_arg(vaList, int);
     while (vaEntry != AUD_END) {
@@ -212,10 +230,6 @@ printbuf(FILE *out, int rec, char *audEvent, afs_int32 errCode, va_list vaList)
 	    vaLong = va_arg(vaList, afs_int32);
 	    fprintf(out, "LONG %d ", vaLong);
 	    break;
-	case AUD_LST:		/* Ptr to another list */
-	    vaLst = va_arg(vaList, va_list);
-	    printbuf(out, 1, "VALST", 0, vaLst);
-	    break;
 	case AUD_FID:		/* AFSFid - contains 3 entries */
 	    vaFid = va_arg(vaList, struct AFSFid *);
 	    if (vaFid)
@@ -226,24 +240,21 @@ printbuf(FILE *out, int rec, char *audEvent, afs_int32 errCode, va_list vaList)
 	    break;
 	case AUD_FIDS:		/* array of Fids */
 	    vaFids = va_arg(vaList, struct AFSCBFids *);
-	    vaFid = NULL;
 
 	    if (vaFids) {
                 int i;
-                if (vaFid)
+                
+                vaFid = vaFids->AFSCBFids_val;
+                
+                if (vaFid) {
                     fprintf(out, "FIDS %u FID %u:%u:%u ", vaFids->AFSCBFids_len, vaFid->Volume,
                              vaFid->Vnode, vaFid->Unique);
-                else
+                    for ( i = 1; i < vaFids->AFSCBFids_len; i++, vaFid++ ) 
+                        fprintf(out, "FID %u:%u:%u ", vaFid->Volume,
+                                vaFid->Vnode, vaFid->Unique);
+                } else
                     fprintf(out, "FIDS 0 FID 0:0:0 ");
 
-                for ( i = 1; i < vaFids->AFSCBFids_len; i++ ) {
-                    vaFid = vaFids->AFSCBFids_val;
-                    if (vaFid)
-                        fprintf(out, "FID %u:%u:%u ", vaFid->Volume,
-                                 vaFid->Vnode, vaFid->Unique);
-                    else
-                        fprintf(out, "FID 0:0:0 ");
-                }
             }
 	    break;
 	default:
@@ -253,8 +264,7 @@ printbuf(FILE *out, int rec, char *audEvent, afs_int32 errCode, va_list vaList)
 	vaEntry = va_arg(vaList, int);
     }				/* end while */
 
-    if (strcmp(audEvent, "VALST") != 0)
-	fprintf(out, "\n");
+    fprintf(out, "\n");
 }
 
 #ifdef AFS_PTHREAD_ENV
@@ -284,9 +294,11 @@ osi_audit_init(void)
 /* The routine that acually does the audit call.
  * ************************************************************************** */
 int
-osi_audit(char *audEvent,	/* Event name (15 chars or less) */
-	  afs_int32 errCode,	/* The error code */
-	  ...)
+osi_audit_internal(char *audEvent,	/* Event name (15 chars or less) */
+		   afs_int32 errCode,	/* The error code */
+		   char *afsName,
+		   afs_int32 hostId,
+		   va_list vaList)
 {
 #ifdef AFS_AIX32_ENV
     afs_int32 code;
@@ -294,7 +306,7 @@ osi_audit(char *audEvent,	/* Event name (15 chars or less) */
     static char BUFFER[32768];
 #endif
     int result;
-    va_list vaList;
+    va_list vaCopy;
 
 #ifdef AFS_PTHREAD_ENV
     /* i'm pretty sure all the server apps now call osi_audit_init(),
@@ -308,6 +320,8 @@ osi_audit(char *audEvent,	/* Event name (15 chars or less) */
     if (!osi_audit_all && !auditout)
 	return 0;
 
+    va_copy(vaCopy, vaList);
+
     switch (errCode) {
     case 0:
 	result = AUDIT_OK;
@@ -342,30 +356,20 @@ osi_audit(char *audEvent,	/* Event name (15 chars or less) */
     *(int *)bufferPtr = errCode;
     bufferPtr += sizeof(errCode);
 
-    va_start(vaList, errCode);
     audmakebuf(audEvent, vaList);
 #endif
 
     if (osi_echo_trail) {
-	va_start(vaList, errCode);
-	printbuf(stdout, 0, audEvent, errCode, vaList);
+	printbuf(stdout, 0, audEvent, afsName, hostId, errCode, vaList);
     }
+    va_end(vaCopy);
 
 #ifdef AFS_AIX32_ENV
     bufferLen = (int)((afs_int32) bufferPtr - (afs_int32) & BUFFER[0]);
     code = auditlog(audEvent, result, BUFFER, bufferLen);
-#ifdef notdef
-    if (code) {
-	err = errno;
-	code = auditlog("AFS_Aud_Fail", result, &err, sizeof(err));
-	if (code)
-	    printf("Error while writing audit entry: %d.\n", errno);
-    }
-#endif /* notdef */
 #else
     if (auditout) {
-	va_start(vaList, errCode);
-	printbuf(auditout, 0, audEvent, errCode, vaList);
+	printbuf(auditout, 0, audEvent, afsName, hostId, errCode, vaList);
 	fflush(auditout);
     }
 #endif
@@ -375,6 +379,24 @@ osi_audit(char *audEvent,	/* Event name (15 chars or less) */
 
     return 0;
 }
+int
+osi_audit(char *audEvent,	/* Event name (15 chars or less) */
+	  afs_int32 errCode,	/* The error code */
+	  ...)
+{
+    va_list vaList;
+
+    if ((osi_audit_all < 0) || (osi_echo_trail < 0))
+	osi_audit_check();
+    if (!osi_audit_all && !auditout)
+	return 0;
+
+    va_start(vaList, errCode);
+    osi_audit_internal(audEvent, errCode, NULL, 0, vaList);
+    va_end(vaList);
+
+    return 0;
+}
 
 /* ************************************************************************** */
 /* Given a RPC call structure, this routine extracts the name and host id from the 
@@ -429,12 +451,43 @@ osi_auditU(struct rx_call *call, char *audEvent, int errCode, ...)
                     }
                     if ((clen = strlen(tcell))) {
 #if defined(AFS_ATHENA_STDENV) || defined(AFS_KERBREALM_ENV)
-                        static char local_realm[AFS_REALM_SZ] = "";
-                        if (!local_realm[0]) {
-                            if (afs_krb_get_lrealm(local_realm, 0) != 0 /*KSUCCESS*/)
-                                strncpy(local_realm, "UNKNOWN.LOCAL.REALM", AFS_REALM_SZ);
+                        static char local_realms[AFS_NUM_LREALMS][AFS_REALM_SZ];
+			static int  num_lrealms = -1;
+			int i, lrealm_match;
+
+			if (num_lrealms == -1) {
+			    for (i=0; i<AFS_NUM_LREALMS; i++) {
+				if (afs_krb_get_lrealm(local_realms[i], i) != 0 /*KSUCCESS*/)
+				    break;
+			    }
+
+			    if (i == 0)
+				strncpy(local_realms[0], "UNKNOWN.LOCAL.REALM", AFS_REALM_SZ);
+			    num_lrealms = i;
                         }
-                        if (strcasecmp(local_realm, tcell)) {
+
+			/* Check to see if the ticket cell matches one of the local realms */
+			lrealm_match = 0;
+			for ( i=0;i<num_lrealms;i++ ) {
+			    if (!strcasecmp(local_realms[i], tcell)) {
+				lrealm_match = 1;
+				break;
+			    }
+			}
+			/* If yes, then make sure that the name is not present in 
+  			 * an exclusion list */
+			if (lrealm_match) {
+			    char uname[256];
+			    if (inst[0])
+				snprintf(uname,sizeof(uname),"%s.%s@%s",name,inst,tcell);
+			    else
+				snprintf(uname,sizeof(uname),"%s@%s",name,tcell);
+
+			    if (afs_krb_exclusion(uname))
+				lrealm_match = 0;
+			}
+
+			if (!lrealm_match) {	
                             if (strlen(vname) + 1 + clen >= sizeof(vname))
                                 goto done;
                             strcat(vname, "@");
@@ -461,9 +514,8 @@ osi_auditU(struct rx_call *call, char *audEvent, int errCode, ...)
 	osi_audit("AFS_Aud_NoCall", (-1), AUD_STR, audEvent, AUD_END);
     }
     va_start(vaList, errCode);
-    osi_audit(audEvent, errCode, AUD_NAME, afsName, AUD_HOST, hostId, 
-              AUD_LST, vaList, AUD_END);
-
+    osi_audit_internal(audEvent, errCode, afsName, hostId, vaList);
+    va_end(vaList);
     return 0;
 }
 
@@ -474,7 +526,7 @@ osi_auditU(struct rx_call *call, char *audEvent, int errCode, ...)
  * ************************************************************************** */
 
 int
-osi_audit_check()
+osi_audit_check(void)
 {
     FILE *fds;
     int onoff;
@@ -510,8 +562,35 @@ osi_audit_check()
 }
 
 int
-osi_audit_file(FILE *out)
+osi_audit_file(char *fileName)
 {
-    auditout = out;
+    int tempfd, flags;
+    char oldName[MAXPATHLEN];
+    
+#ifndef AFS_NT40_ENV
+    struct stat statbuf;
+    
+    if ((lstat(fileName, &statbuf) == 0)
+        && (S_ISFIFO(statbuf.st_mode))) {
+        flags = O_WRONLY | O_NONBLOCK;
+    } else 
+#endif
+    {
+        strcpy(oldName, fileName);
+        strcat(oldName, ".old");
+        renamefile(fileName, oldName);
+        flags = O_WRONLY | O_TRUNC | O_CREAT;
+    }
+    tempfd = open(fileName, flags, 0666);
+    if (tempfd > -1) {
+        auditout = fdopen(tempfd, "a");
+        if (!auditout) {
+            printf("Warning: auditlog %s not writable, ignored.\n", fileName);
+            return 1;
+        }
+    } else { 
+        printf("Warning: auditlog %s not writable, ignored.\n", fileName);
+        return 1;
+    }
     return 0;
 }
