@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/bozo/bosserver.c,v 1.32.2.12 2008/10/18 15:09:07 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/bozo/bosserver.c,v 1.32.2.17 2009/03/16 17:52:48 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -40,18 +40,20 @@ RCSID
 #include "bnode.h"
 #include "bosprototypes.h"
 #include <rx/rxkad.h>
+#include <rx/rxstat.h>
+#include <rx/rxstat_prototypes.h>
 #include <afs/keys.h>
 #include <afs/ktime.h>
 #include <afs/afsutil.h>
 #include <afs/fileutil.h>
 #include <afs/procmgmt.h>	/* signal(), kill(), wait(), etc. */
+#include <afs/audit.h>
+#include <afs/cellconfig.h>
 #if defined(AFS_SGI_ENV)
 #include <afs/afs_args.h>
 #endif
 
 #define BOZO_LWP_STACKSIZE	16000
-extern int BOZO_ExecuteRequest();
-extern int RXSTATS_ExecuteRequest();
 extern struct bnode_ops fsbnode_ops, dafsbnode_ops, ezbnode_ops, cronbnode_ops;
 
 struct afsconf_dir *bozo_confdir = 0;	/* bozo configuration dir */
@@ -102,7 +104,7 @@ bozo_rxstat_userok(struct rx_call *call)
 
 /* restart bozo process */
 int
-bozo_ReBozo()
+bozo_ReBozo(void)
 {
 #ifdef AFS_NT40_ENV
     /* exit with restart code; SCM integrator process will restart bosserver */
@@ -187,7 +189,7 @@ MakeDir(const char *adir)
 
 /* create all the bozo dirs */
 static int
-CreateDirs()
+CreateDirs(void)
 {
     if ((!strncmp
 	 (AFSDIR_USR_DIRPATH, AFSDIR_CLIENT_ETC_DIRPATH,
@@ -239,9 +241,10 @@ StripLine(register char *abuffer)
 }
 
 /* write one bnode's worth of entry into the file */
-static
-bzwrite(register struct bnode *abnode, register struct bztemp *at)
+static int
+bzwrite(register struct bnode *abnode, void *arock)
 {
+    register struct bztemp *at = (struct bztemp *)arock;
     register int i;
     char tbuffer[BOZO_BSSIZE];
     register afs_int32 code;
@@ -494,7 +497,7 @@ WriteBozoFile(char *aname)
 }
 
 static int
-bdrestart(register struct bnode *abnode, char *arock)
+bdrestart(register struct bnode *abnode, void *arock)
 {
     register afs_int32 code;
 
@@ -555,7 +558,7 @@ BozoDaemon(void *unused)
 
 #ifdef AFS_AIX32_ENV
 static int
-tweak_config()
+tweak_config(void)
 {
     FILE *f;
     char c[80];
@@ -833,41 +836,16 @@ main(int argc, char **argv, char **envp)
 	    rxMaxMTU = atoi(argv[++code]);
 	    if ((rxMaxMTU < RX_MIN_PACKET_SIZE) || 
 		(rxMaxMTU > RX_MAX_PACKET_DATA_SIZE)) {
-		printf("rxMaxMTU %d invalid; must be between %d-%d\n",
+		printf("rxMaxMTU %d invalid; must be between %d-%lu\n",
 			rxMaxMTU, RX_MIN_PACKET_SIZE, 
 			RX_MAX_PACKET_DATA_SIZE);
 		exit(1);
 	    }
 	}
 	else if (strcmp(argv[code], "-auditlog") == 0) {
-	    int tempfd, flags;
-	    FILE *auditout;
-	    char oldName[MAXPATHLEN];
 	    char *fileName = argv[++code];
 
-#ifndef AFS_NT40_ENV
-	    struct stat statbuf;
-	    
-	    if ((lstat(fileName, &statbuf) == 0) 
-		&& (S_ISFIFO(statbuf.st_mode))) {
-		flags = O_WRONLY | O_NONBLOCK;
-	    } else 
-#endif
-	    {
-		strcpy(oldName, fileName);
-		strcat(oldName, ".old");
-		renamefile(fileName, oldName);
-		flags = O_WRONLY | O_TRUNC | O_CREAT;
-	    }
-	    tempfd = open(fileName, flags, 0666);
-	    if (tempfd > -1) {
-		auditout = fdopen(tempfd, "a");
-		if (auditout) {
-		    osi_audit_file(auditout);
-		} else
-		    printf("Warning: auditlog %s not writable, ignored.\n", fileName);
-	    } else
-		printf("Warning: auditlog %s not writable, ignored.\n", fileName);
+            osi_audit_file(fileName);
 	}
 	else {
 
@@ -971,7 +949,7 @@ main(int argc, char **argv, char **envp)
     }
 
     code = LWP_CreateProcess(BozoDaemon, BOZO_LWP_STACKSIZE, /* priority */ 1,
-			     (void *) /*parm */ 0, "bozo-the-clown",
+			     /* param */ NULL , "bozo-the-clown",
 			     &bozo_pid);
 
     /* try to read the key from the config file */
@@ -1010,7 +988,7 @@ main(int argc, char **argv, char **envp)
     }
 
     /* read init file, starting up programs */
-    if (code = ReadBozoFile(0)) {
+    if ((code = ReadBozoFile(0))) {
 	bozo_Log
 	    ("bosserver: Something is wrong (%d) with the bos configuration file %s; aborting\n",
 	     code, AFSDIR_SERVER_BOZCONF_FILEPATH);
@@ -1041,7 +1019,6 @@ main(int argc, char **argv, char **envp)
 
     if (rxBind) {
 	afs_int32 ccode;
-#ifndef AFS_NT40_ENV
         if (AFSDIR_SERVER_NETRESTRICT_FILEPATH || 
             AFSDIR_SERVER_NETINFO_FILEPATH) {
             char reason[1024];
@@ -1050,7 +1027,6 @@ main(int argc, char **argv, char **envp)
                                            AFSDIR_SERVER_NETINFO_FILEPATH,
                                            AFSDIR_SERVER_NETRESTRICT_FILEPATH);
         } else 
-#endif	
 	{
             ccode = rx_getAllAddr(SHostAddrs, ADDRSPERSITE);
         }
