@@ -15,7 +15,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/bucoord/restore.c,v 1.10.6.8 2008/10/18 15:23:24 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/bucoord/restore.c,v 1.10.6.9 2009/03/16 13:32:14 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -36,6 +36,7 @@ RCSID
 #include <afs/budb.h>
 #include <afs/vlserver.h>
 #include "error_macros.h"
+#include "bucoord_prototypes.h"
 
 extern struct bc_dumpTask bc_dumpTasks[BC_MAXSIMDUMPS];
 extern char *whoami;
@@ -92,13 +93,12 @@ struct bc_tapeItem {
 };
 
 /* strip .backup from the end of a name */
-static
-StripBackup(aname)
-     register char *aname;
+static int
+StripBackup(char *aname)
 {
     int j;
 
-    if (j = BackupName(aname)) {
+    if ((j = BackupName(aname))) {
 	aname[j] = 0;
 	return 0;
     }
@@ -106,8 +106,7 @@ StripBackup(aname)
 }
 
 int
-BackupName(aname)
-     char *aname;
+BackupName(char *aname)
 {
     int j;
 
@@ -119,8 +118,8 @@ BackupName(aname)
     return 0;
 }
 
-extractTapeSeq(tapename)
-     char *tapename;
+int
+extractTapeSeq(char *tapename)
 {
     char *sptr;
 
@@ -132,8 +131,7 @@ extractTapeSeq(tapename)
 }
 
 void
-viceName(value)
-     long value;
+viceName(long value)
 {
     char *alph;
     int r;
@@ -151,8 +149,8 @@ viceName(value)
  * entry:
  *	aindex - index into bc_dumpTasks that describes this dump.
  */
-bc_Restorer(aindex)
-     afs_int32 aindex;
+int
+bc_Restorer(afs_int32 aindex)
 {
     struct bc_dumpTask *dumpTaskPtr;
 
@@ -184,7 +182,7 @@ bc_Restorer(aindex)
 
     struct dumpinfo *dumpinfolist = NULL;
     struct dumpinfo *pdi, *ndi, *di, *dlevels;
-    struct volinfo *pvi, *nvi, *vi;
+    struct volinfo *nvi, *vi;
     afs_int32 lvl, lv;
     int num_dlevels = 20;
 
@@ -195,9 +193,6 @@ bc_Restorer(aindex)
     time_t did;
     int foundtape, c;
 
-    extern statusP createStatusNode();
-    extern statusP findStatus();
-
     dlevels = (struct dumpinfo *) malloc(num_dlevels * sizeof(*dlevels));
 
     dumpTaskPtr = &bc_dumpTasks[aindex];
