@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/cmd/cmd.c,v 1.10 2003/07/15 23:14:50 shadow Exp $");
+    ("$Header: /cvs/openafs/src/cmd/cmd.c,v 1.12.4.3 2008/01/13 15:35:41 jaltman Exp $");
 
 #include <sys/types.h>
 #include <ctype.h>
@@ -30,9 +30,9 @@ struct cmd_token {
 static int dummy;		/* non-null ptr used for flag existence */
 static struct cmd_syndesc *allSyntax = 0;
 static int noOpcodes = 0;
-static int (*beforeProc) (struct cmd_syndesc * ts, char *beforeRock) =
-    0, (*afterProc) (struct cmd_syndesc * ts, char *afterRock) = 0;
-static char *beforeRock, *afterRock;
+static int (*beforeProc) (struct cmd_syndesc * ts, void *beforeRock) = NULL;
+static int (*afterProc) (struct cmd_syndesc * ts, void *afterRock) = NULL;
+static void *beforeRock, *afterRock;
 static char initcmd_opcode[] = "initcmd";	/*Name of initcmd opcode */
 
 /* take name and string, and return null string if name is empty, otherwise return
@@ -40,13 +40,14 @@ static char initcmd_opcode[] = "initcmd";	/*Name of initcmd opcode */
 static char *
 NName(char *a1, char *a2)
 {
-    static char tbuffer[80];
+    static char tbuffer[300];
     if (strlen(a1) == 0) {
-	return "";
+        return "";
     } else {
-	strcpy(tbuffer, a1);
-	strcat(tbuffer, a2);
-	return tbuffer;
+        strncpy(tbuffer, a1, sizeof(tbuffer));
+        strncat(tbuffer, a2, sizeof(tbuffer));
+        tbuffer[sizeof(tbuffer)-1]='\0';
+        return tbuffer;
     }
 }
 
@@ -56,8 +57,8 @@ SubString(register char *amain, register char *asub)
 {
     int mlen, slen;
     register int i, j;
-    mlen = strlen(amain);
-    slen = strlen(asub);
+    mlen = (int) strlen(amain);
+    slen = (int) strlen(asub);
     j = mlen - slen;
     if (j < 0)
 	return 0;		/* not a substring */
@@ -165,6 +166,15 @@ PrintParmHelp(register struct cmd_parmdesc *aparm)
 	printf(" <arg>+");
 }
 
+extern char *AFSVersion;
+
+static int
+VersionProc(register struct cmd_syndesc *as, void *arock)
+{
+    printf("%s\n", AFSVersion);
+    return 0;
+}
+
 void
 PrintSyntax(register struct cmd_syndesc *as)
 {
@@ -263,7 +273,7 @@ PrintFlagHelp(register struct cmd_syndesc *as)
 }
 
 static int
-AproposProc(register struct cmd_syndesc *as, char *arock)
+AproposProc(register struct cmd_syndesc *as, void *arock)
 {
     register struct cmd_syndesc *ts;
     char *tsub;
@@ -288,7 +298,7 @@ AproposProc(register struct cmd_syndesc *as, char *arock)
 }
 
 static int
-HelpProc(register struct cmd_syndesc *as, char *arock)
+HelpProc(register struct cmd_syndesc *as, void *arock)
 {
     register struct cmd_syndesc *ts;
     register struct cmd_item *ti;
@@ -335,8 +345,8 @@ HelpProc(register struct cmd_syndesc *as, char *arock)
 }
 
 int
-cmd_SetBeforeProc(int (*aproc) (struct cmd_syndesc * ts, char *beforeRock),
-		  char *arock)
+cmd_SetBeforeProc(int (*aproc) (struct cmd_syndesc * ts, void *beforeRock),
+		  void *arock)
 {
     beforeProc = aproc;
     beforeRock = arock;
@@ -344,8 +354,8 @@ cmd_SetBeforeProc(int (*aproc) (struct cmd_syndesc * ts, char *beforeRock),
 }
 
 int
-cmd_SetAfterProc(int (*aproc) (struct cmd_syndesc * ts, char *afterRock),
-		 char *arock)
+cmd_SetAfterProc(int (*aproc) (struct cmd_syndesc * ts, void *afterRock),
+		 void *arock)
 {
     afterProc = aproc;
     afterRock = arock;
@@ -371,8 +381,8 @@ SortSyntax(struct cmd_syndesc *as)
 
 struct cmd_syndesc *
 cmd_CreateSyntax(char *aname,
-		 int (*aproc) (struct cmd_syndesc * ts, char *arock),
-		 char *arock, char *ahelp)
+		 int (*aproc) (struct cmd_syndesc * ts, void *arock),
+		 void *arock, char *ahelp)
 {
     register struct cmd_syndesc *td;
 
@@ -472,7 +482,7 @@ cmd_AddParm(register struct cmd_syndesc *as, char *aname, int atype,
     strcpy(tp->name, aname);
     tp->type = atype;
     tp->flags = aflags;
-    tp->items = (struct cmd_item *)0;
+    tp->items = NULL;
     if (ahelp) {
 	tp->help = (char *)malloc(strlen(ahelp) + 1);
 	assert(tp->help);
@@ -547,7 +557,7 @@ ResetSyntax(register struct cmd_syndesc *as)
 	default:
 	    break;
 	}
-	tp->items = (struct cmd_item *)0;
+	tp->items = NULL;
     }
 }
 
@@ -594,6 +604,7 @@ InsertInitOpcode(int *aargc, char **aargv)
     pinitopcode = (char *)malloc(sizeof(initcmd_opcode));
     if (!pinitopcode) {
 	fprintf(stderr, "%s: Can't malloc initial opcode space\n", aargv[0]);
+	free(newargv);
 	return (NULL);
     }
     strcpy(pinitopcode, initcmd_opcode);
@@ -657,6 +668,16 @@ cmd_Dispatch(int argc, char **argv)
 				  "search by help text");
 	    cmd_AddParm(ts, "-topic", CMD_SINGLE, CMD_REQUIRED,
 			"help string");
+	    ts = cmd_CreateSyntax("version", VersionProc, (char *)0,
+				  (char *)CMD_HIDDEN);
+	    ts = cmd_CreateSyntax("-version", VersionProc, (char *)0,
+				  (char *)CMD_HIDDEN);
+	    ts = cmd_CreateSyntax("-help", HelpProc, (char *)0,
+				  (char *)CMD_HIDDEN);
+	    ts = cmd_CreateSyntax("--version", VersionProc, (char *)0,
+				  (char *)CMD_HIDDEN);
+	    ts = cmd_CreateSyntax("--help", HelpProc, (char *)0,
+				  (char *)CMD_HIDDEN);
 	}
     }
 
