@@ -39,6 +39,7 @@
 #define AFS_64BIT_CLIENT	1	
 
 #define AFS_64BITPOINTER_ENV	1	/* pointers are 64 bits. */
+#define AFS_MAXVCOUNT_ENV       1
 
 #if defined(__KERNEL__) && !defined(KDUMP_KERNEL)
 
@@ -124,6 +125,7 @@
 #define AFS_MOUNT_AFS "afs"	/* The name of the filesystem type. */
 #define AFS_SYSCALL 1141
 #define AFS_64BIT_IOPS_ENV  1
+#define AFS_64BIT_ENV		1
 #define AFS_NAMEI_ENV     1	/* User space interface to file system */
 #include <afs/afs_sysnames.h>
 
