@@ -172,8 +172,9 @@ struct cm_initparams {
 #define VIOC_RXSTAT_PEER	_VICEIOCTL(54)	/* Control peer RX stats */
 #define VIOC_GETRXKCRYPT        _VICEIOCTL(55)	/* Set rxkad enc flag */
 #define VIOC_SETRXKCRYPT        _VICEIOCTL(56)	/* Set rxkad enc flag */
-#define VIOC_PREFETCHTAPE       _VICEIOCTL(66)	/* MR-AFS prefetch from tape */
-#define VIOC_RESIDENCY_CMD      _VICEIOCTL(67)	/* generic MR-AFS cmds */
+#define VIOC_PREFETCHTAPE       _VICEIOCTL(66)	/* osd prefetch from tape */
+#define VIOC_FS_CMD      	_VICEIOCTL(67)	/* fs extensions for osd etc. */
+#define VIOC_RESIDENCY_CMD      VIOC_FS_CMD
 #define VIOC_STATISTICS         _VICEIOCTL(68)	/* arla: fetch statistics */
 #define VIOC_GETVCXSTATUS2      _VICEIOCTL(69)  /* vcache statistics */
 
