@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/kauth/rebuild.c,v 1.13.2.1 2007/04/10 18:39:52 shadow Exp $");
+    ("$Header: /cvs/openafs/src/kauth/rebuild.c,v 1.13.2.6 2009/03/17 04:45:10 shadow Exp $");
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -23,13 +23,7 @@ RCSID
 #include <sys/file.h>
 #include <netinet/in.h>
 #endif
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 #include <stdio.h>
 #include <errno.h>
 #include <time.h>
@@ -49,12 +43,12 @@ char *whoami = "kadb_check";
 int fd;
 FILE *out;
 
-void badEntry();
+void badEntry(afs_int32, afs_int32);
 
 int listuheader, listkheader, listentries, verbose;
 
 int
-readUbikHeader()
+readUbikHeader(void)
 {
     int offset, r;
     struct ubik_hdr uheader;
@@ -68,7 +62,7 @@ readUbikHeader()
     /* now read the info */
     r = read(fd, &uheader, sizeof(uheader));
     if (r != sizeof(uheader)) {
-	printf("error: read of %d bytes failed: %d %d\n", sizeof(uheader), r,
+	printf("error: read of %lu bytes failed: %d %d\n", sizeof(uheader), r,
 	       errno);
 	return (-1);
     }
@@ -97,8 +91,7 @@ readUbikHeader()
 }
 
 void
-PrintHeader(header)
-     struct kaheader *header;
+PrintHeader(struct kaheader *header)
 {
     printf("Version          = %d\n", header->version);
     printf("HeaderSize       = %d\n", header->headerSize);
@@ -116,9 +109,7 @@ PrintHeader(header)
 }
 
 void
-PrintEntry(index, entry)
-     afs_int32 index;
-     struct kaentry *entry;
+PrintEntry(afs_int32 index, struct kaentry *entry)
 {
     int i;
     char Time[100];
@@ -223,6 +214,7 @@ PrintEntry(index, entry)
 }
 
 /* ntohEntry - convert back to host-order */
+void
 ntohEntry(struct kaentry *entryp)
 {
     entryp->flags = ntohl(entryp->flags);
@@ -239,8 +231,7 @@ ntohEntry(struct kaentry *entryp)
 
 char principal[64];
 char *
-EntryName(entryp)
-     struct kaentry *entryp;
+EntryName(struct kaentry *entryp)
 {
     char name[32], inst[32];
 
@@ -259,8 +250,7 @@ EntryName(entryp)
 }
 
 void
-RebuildEntry(entryp)
-     struct kaentry *entryp;
+RebuildEntry(struct kaentry *entryp)
 {
     char key[33];
     char flags[128];
@@ -310,8 +300,8 @@ RebuildEntry(entryp)
 	    ntohl(entryp->key_version));
 }
 
-CheckHeader(header)
-     struct kaheader *header;
+int
+CheckHeader(struct kaheader *header)
 {
     afs_int32 i, code = 0;
 
@@ -340,7 +330,7 @@ CheckHeader(header)
     if (header->headerSize != sizeof(struct kaheader)) {
 	code++;
 	fprintf(stderr,
-		"HEADER SIZE WRONG: file indicates %d, should be %d\n",
+		"HEADER SIZE WRONG: file indicates %d, should be %lu\n",
 		header->headerSize, sizeof(struct kaheader));
     }
     if (header->hashsize != HASHSIZE) {
@@ -367,8 +357,7 @@ CheckHeader(header)
 }
 
 afs_int32
-NameHash(entryp)
-     struct kaentry *entryp;
+NameHash(struct kaentry *entryp)
 {
     unsigned int hash;
     int i;
@@ -384,10 +373,8 @@ NameHash(entryp)
     return (hash % HASHSIZE);
 }
 
-readDB(offset, buffer, size)
-     afs_int32 offset;
-     char *buffer;
-     afs_int32 size;
+int
+readDB(afs_int32 offset, void *buffer, afs_int32 size)
 {
     afs_int32 code;
 
@@ -402,13 +389,13 @@ readDB(offset, buffer, size)
 	afs_com_err(whoami, errno, "reading db got %d bytes", code);
 	exit(3);
     }
+    return 0;
 }
 
 #include "AFS_component_version_number.c"
 
-WorkerBee(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+static int
+WorkerBee(struct cmd_syndesc *as, void *arock)
 {
     afs_int32 code;
     char *dbFile;
@@ -449,7 +436,7 @@ WorkerBee(as, arock)
     if ((info.st_size - UBIK_HEADERSIZE) % UBIK_BUFFERSIZE)
 	fprintf(stderr,
 		"DATABASE SIZE INCONSISTENT: was %d, should be (n*%d + %d), for integral n\n",
-		info.st_size, UBIK_BUFFERSIZE, UBIK_HEADERSIZE);
+		(int) info.st_size, UBIK_BUFFERSIZE, UBIK_HEADERSIZE);
 
     readUbikHeader();
 
@@ -516,7 +503,7 @@ WorkerBee(as, arock)
 	    i = NameHash(&entry);
 	    if (i != j) {
 		fprintf(stderr,
-			"Entry %d, %s, found in hash chain %d (should be %d)\n",
+			"Entry %lu, %s, found in hash chain %d (should be %d)\n",
 			((index -
 			  sizeof(struct kaheader)) / sizeof(struct kaentry)),
 			EntryName(&entry), j, i);
@@ -615,8 +602,7 @@ WorkerBee(as, arock)
 }
 
 void
-badEntry(e, i)
-     afs_int32 e, i;
+badEntry(afs_int32 e, afs_int32 i)
 {
     int offset;
     struct kaentry entry;
@@ -648,9 +634,8 @@ badEntry(e, i)
     fprintf(stderr, " ]\n");
 }
 
-main(argc, argv)
-     int argc;
-     char *argv[];
+int
+main(int argc, char **argv)
 {
     struct cmd_syndesc *ts;
 
