@@ -23,7 +23,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/lwp/waitkey.c,v 1.13.14.1 2007/10/30 15:16:42 shadow Exp $");
+    ("$Header: /cvs/openafs/src/lwp/waitkey.c,v 1.13.14.2 2009/04/27 18:31:56 shadow Exp $");
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -166,8 +166,23 @@ LWP_WaitForKeystroke(int seconds)
 	return 1;
 #else
 #if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
+#if defined(AFS_DFBSD_ENV)
+    struct appx_sbuf {
+      unsigned char *_base;
+      int     _size;
+    };
+    struct APPX_FILE
+    {      
+      struct __FILE_public    pub;
+      struct  appx_sbuf _bf;     /* the buffer (at least 1 byte, if !NULL) */
+    };
+    struct APPX_FILE *appx_stdin = (struct APPX_FILE *) stdin;
+    if (appx_stdin->_bf._size > 0)
+	return 1;
+#else
     if (stdin->_bf._size > 0)
 	return 1;
+#endif
 #else
     if (stdin->_cnt > 0)
 	return 1;
