@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/pam/afs_auth.c,v 1.13.4.1 2008/08/26 14:11:46 shadow Exp $");
+    ("$Header: /cvs/openafs/src/pam/afs_auth.c,v 1.13.4.2 2009/04/27 18:31:56 shadow Exp $");
 
 #include <syslog.h>
 #include <stdlib.h>
@@ -190,7 +190,7 @@ pam_sm_authenticate(pam_handle_t * pamh, int flags, int argc,
 	RET(PAM_AUTH_ERR);
     }
 #else
-#if     defined(AFS_LINUX20_ENV) || defined(AFS_FBSD_ENV) || defined(AFS_NBSD_ENV)
+#if     defined(AFS_LINUX20_ENV) || defined(AFS_FBSD_ENV) || defined(AFS_DFBSD_ENV) || defined(AFS_NBSD_ENV)
     upwd = getpwnam(user);
 #elif   defined(_POSIX_PTHREAD_SEMANTICS) && defined(AFS_SUN5_ENV)
     getpwnam_r(user, &unix_pwd, upwd_buf, sizeof(upwd_buf), &upwd);
