@@ -15,7 +15,7 @@
 #endif
 
 RCSID
-    ("$Header: /cvs/openafs/src/ptserver/ptuser.c,v 1.25.2.10 2007/04/10 18:39:54 shadow Exp $");
+    ("$Header: /cvs/openafs/src/ptserver/ptuser.c,v 1.25.2.14 2009/05/12 19:40:32 shadow Exp $");
 
 #if defined(UKERNEL)
 #include "afs/sysincludes.h"
@@ -40,13 +40,7 @@ RCSID
 #include <netinet/in.h>
 #endif
 #include <stdio.h>
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 #include <rx/rx.h>
 #include <rx/xdr.h>
 #include <afs/auth.h>
@@ -97,11 +91,12 @@ pr_Initialize(IN afs_int32 secLevel, IN const char *confDir, IN char *cell)
 	if (!tdir) {
 	    if (confDir && strcmp(confDir, ""))
 		fprintf(stderr,
-			"libprot: Could not open configuration directory: %s.\n",
-			confDir);
+			"%s: Could not open configuration directory: %s.\n",
+			whoami, confDir);
             else
 		fprintf(stderr,
-			"libprot: No configuration directory specified.\n");
+			"%s: No configuration directory specified.\n",
+			whoami);
 	    return -1;
 	}
         gottdir = 1;
@@ -179,16 +174,22 @@ pr_Initialize(IN afs_int32 secLevel, IN const char *confDir, IN char *cell)
     /* Most callers use secLevel==1, however, the fileserver uses secLevel==2
      * to force use of the KeyFile.  secLevel == 0 implies -noauth was
      * specified. */
-    if ((secLevel == 2) && (afsconf_GetLatestKey(tdir, 0, 0) == 0)) {
-	/* If secLevel is two assume we're on a file server and use
-	 * ClientAuthSecure if possible. */
-	code = afsconf_ClientAuthSecure(tdir, &sc[2], &scIndex);
-	if (code)
-	    fprintf(stderr,
-		    "libprot: clientauthsecure returns %d %s"
-		    " (so trying noauth)\n", code, afs_error_message(code));
-	if (code)
-	    scIndex = 0;	/* use noauth */
+    if (secLevel == 2) {
+	code = afsconf_GetLatestKey(tdir, 0, 0);
+	if (code) {
+	    afs_com_err(whoami, code, 
+			"(getting key from local KeyFile)\n");
+	    scIndex = 0; /* use noauth */
+	} else {
+	    /* If secLevel is two assume we're on a file server and use
+	     * ClientAuthSecure if possible. */
+	    code = afsconf_ClientAuthSecure(tdir, &sc[2], &scIndex);
+	    if (code) {
+		afs_com_err(whoami, code,
+			    "(calling client secure)\n");
+		scIndex = 0;	/* use noauth */
+	    }
+        }
 	if (scIndex != 2)
 	    /* if there was a problem, an unauthenticated conn is returned */
 	    sc[scIndex] = sc[2];
@@ -198,20 +199,24 @@ pr_Initialize(IN afs_int32 secLevel, IN const char *confDir, IN char *cell)
 	sname.instance[0] = 0;
 	strcpy(sname.name, "afs");
 	code = ktc_GetToken(&sname, &ttoken, sizeof(ttoken), NULL);
-	if (code)
+	if (code) {
+	    afs_com_err(whoami, code, "(getting token)");
+	    if (secLevel > 1)
+		return code;
 	    scIndex = 0;
-	else {
+	} else {
 	    if (ttoken.kvno >= 0 && ttoken.kvno <= 256)
 		/* this is a kerberos ticket, set scIndex accordingly */
 		scIndex = 2;
 	    else {
 		fprintf(stderr,
-			"libprot: funny kvno (%d) in ticket, proceeding\n",
-			ttoken.kvno);
+			"%s: funny kvno (%d) in ticket, proceeding\n",
+			whoami, ttoken.kvno);
 		scIndex = 2;
 	    }
 	    sc[2] =
-		rxkad_NewClientSecurityObject(rxkad_clear, &ttoken.sessionKey,
+		rxkad_NewClientSecurityObject((secLevel > 1) ? rxkad_crypt :
+					      rxkad_clear, &ttoken.sessionKey,
 					      ttoken.kvno, ttoken.ticketLen,
 					      ttoken.ticket);
 	}
@@ -222,8 +227,9 @@ pr_Initialize(IN afs_int32 secLevel, IN const char *confDir, IN char *cell)
     if ((scIndex == 0) && (sc[0] == 0))
 	sc[0] = rxnull_NewClientSecurityObject();
     if ((scIndex == 0) && (secLevel != 0))
-	afs_com_err(whoami, code,
-		"Could not get afs tokens, running unauthenticated.");
+	fprintf(stderr,
+		"%s: Could not get afs tokens, running unauthenticated\n",
+		whoami);
 
     memset(serverconns, 0, sizeof(serverconns));	/* terminate list!!! */
     for (i = 0; i < info.numServers; i++)
@@ -244,7 +250,7 @@ pr_Initialize(IN afs_int32 secLevel, IN const char *confDir, IN char *cell)
 }
 
 int
-pr_End()
+pr_End(void)
 {
     int code = 0;
 
