@@ -11,35 +11,29 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/ptserver/readgroup.c,v 1.9 2004/04/18 06:13:50 kolya Exp $");
+    ("$Header: /cvs/openafs/src/ptserver/readgroup.c,v 1.10.14.4 2009/03/16 13:08:57 shadow Exp $");
 
 #include <stdio.h>
 #ifdef AFS_NT40_ENV
 #include <WINNT/afsevent.h>
 #endif
 #include <ctype.h>
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 #include <rx/rx.h>
 #include <rx/xdr.h>
 #include <afs/cellconfig.h>
 #include <afs/afsutil.h>
+#include <afs/com_err.h>
 #include "ptclient.h"
+#include "ptuser.h"
 #include "pterror.h"
+#include "ptprototypes.h"
 
 int verbose = 0;
-void skip();
+static void skip(char **);
 
 void
-report_error(code, name, gname)
-     afs_int32 code;
-     char *name;
-     char *gname;
+report_error(afs_int32 code, char *name, char *gname)
 {
     if (code == 0) {
 	if (verbose)
@@ -54,7 +48,7 @@ report_error(code, name, gname)
 }
 
 int
-osi_audit()
+osi_audit(void)
 {
 /* OK, this REALLY sucks bigtime, but I can't tell who is calling
  * afsconf_CheckAuth easily, and only *SERVERS* should be calling osi_audit
@@ -65,9 +59,8 @@ osi_audit()
 
 #include "AFS_component_version_number.c"
 
-main(argc, argv)
-     afs_int32 argc;
-     char **argv;
+int
+main(int argc, char **argv)
 {
     register afs_int32 code;
     char name[PR_MAXNAMELEN];
@@ -215,11 +208,11 @@ main(argc, argv)
 	    }
 	}
     }
+    return 0;
 }
 
-void
-skip(s)
-     char **s;
+static void
+skip(char **s)
 {
     while (**s != ' ' && **s != '\t' && **s != '\0')
 	(*s)++;
