@@ -18,7 +18,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/tviced/state_analyzer.c,v 1.1.4.3 2008/06/30 17:28:47 shadow Exp $");
+    ("$Header: /cvs/openafs/src/tviced/state_analyzer.c,v 1.1.4.4 2009/03/26 21:33:59 shadow Exp $");
 
 #include <stdio.h>
 #include <errno.h>
@@ -246,7 +246,7 @@ static struct {
 static void
 usage(char * prog)
 {
-    fprintf(stderr, "usage: %s [<state dump file>]\n");
+    fprintf(stderr, "usage: %s [<state dump file>]\n", prog);
 }
 
 int
