@@ -11,13 +11,16 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/ubik/lock.c,v 1.13 2003/12/12 23:16:12 shadow Exp $");
+    ("$Header: /cvs/openafs/src/ubik/lock.c,v 1.13.14.2 2009/03/16 03:03:24 shadow Exp $");
 
 #include <sys/types.h>
+#include <stdarg.h>
+#include <errno.h>
+
 #ifndef AFS_NT40_ENV
 #include <sys/file.h>
 #endif
-#include <errno.h>
+
 #include <lock.h>
 #include <rx/xdr.h>
 
@@ -25,7 +28,8 @@ RCSID
 #include "ubik.h"
 #include "ubik_int.h"
 
-/* Locks hang off of each transaction, with all the transaction hanging off of
+/*! \file
+ * Locks hang off of each transaction, with all the transaction hanging off of
  * the appropriate dbase.  This package expects to be used in a two-phase locking
  * protocol, so it doesn't provide a way to release anything but all of the locks in the
  * transaction.
@@ -36,12 +40,12 @@ RCSID
  *
  * It is the responsibility of the user to avoid deadlock by setting locks in a partial order.
  *
- * EWOULDBLOCK has been replaced in this file by EAGAIN. Many Unix's but not
- * all (eg. HP) do not replace EWOULDBLOCK with EAGAIN. The bad news is this
+ * #EWOULDBLOCK has been replaced in this file by #EAGAIN. Many Unix's but not
+ * all (eg. HP) do not replace #EWOULDBLOCK with #EAGAIN. The bad news is this
  * goes over the wire. The good news is that the code path is never triggered
  * as it requires ulock_getLock to be called with await = 0. And ulock_SetLock
  * isn't even used in this code base. Since NT doesn't have a native
- * EAGAIN, we are replacing all instances of EWOULDBLOCK with EAGAIN.
+ * #EAGAIN, we are replacing all instances of #EWOULDBLOCK with #EAGAIN.
  * 
  */
 
@@ -53,15 +57,16 @@ RCSID
 struct Lock rwlock;
 int rwlockinit = 1;
 
-/* Set a transaction lock.  Atype is LOCKREAD or LOCKWRITE, await is
- * true if you want to wait for the lock instead of returning
- * EWOULDLBOCK.
+/*!
+ * \brief Set a transaction lock.
+ * \param atype is #LOCKREAD or #LOCKWRITE.
+ * \param await is TRUE if you want to wait for the lock instead of returning
+ * #EWOULDBLOCK.
  *
- * The DBHOLD lock must be held.
+ * \note The #DBHOLD lock must be held.
  */
-ulock_getLock(atrans, atype, await)
-     struct ubik_trans *atrans;
-     int atype, await;
+extern int
+ulock_getLock(struct ubik_trans *atrans, int atype, int await)
 {
     struct ubik_dbase *dbase = atrans->dbase;
 
@@ -144,10 +149,11 @@ ulock_getLock(atrans, atype, await)
     return 0;
 }
 
-/* Release the transaction lock */
+/*!
+ * \brief Release the transaction lock.
+ */
 void
-ulock_relLock(atrans)
-     struct ubik_trans *atrans;
+ulock_relLock(struct ubik_trans *atrans)
 {
     if (rwlockinit)
 	return;
@@ -167,9 +173,11 @@ ulock_relLock(atrans)
     return;
 }
 
-/* debugging hooks */
-ulock_Debug(aparm)
-     struct ubik_debug *aparm;
+/*!
+ * \brief debugging hooks
+ */
+void
+ulock_Debug(struct ubik_debug *aparm)
 {
     if (rwlockinit) {
 	aparm->anyReadLocks = 0;
@@ -178,5 +186,4 @@ ulock_Debug(aparm)
 	aparm->anyReadLocks = rwlock.readers_reading;
 	aparm->anyWriteLocks = ((rwlock.excl_locked == WRITE_LOCK) ? 1 : 0);
     }
-    return 0;
 }
