@@ -15,11 +15,12 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/util/hostparse.c,v 1.15 2005/11/14 05:46:29 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/util/hostparse.c,v 1.15.4.2 2009/04/27 18:31:57 shadow Exp $");
 
 #ifdef UKERNEL
 #include "afs/sysincludes.h"
 #include "afs/afsutil.h"
+#include <netdb.h>
 #else /* UKERNEL */
 #include <stdio.h>
 #include <sys/types.h>
@@ -34,13 +35,7 @@ RCSID
 #include <netdb.h>
 #include <ctype.h>
 #endif
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 #include <errno.h>
 #include "afsutil.h"
 #endif /* UKERNEL */
