@@ -11,23 +11,16 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/vlserver/vlutils.c,v 1.8 2003/07/15 23:17:34 shadow Exp $");
+    ("$Header: /cvs/openafs/src/vlserver/vlutils.c,v 1.9.14.2 2009/03/23 18:19:06 shadow Exp $");
 
 #include <sys/types.h>
+#include <string.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
 #else
 #include <netinet/in.h>
 #endif
 
-#ifdef HAVE_STRING_H
-#include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
-
 #include <lock.h>
 #include <rx/xdr.h>
 #include <ubik.h>
@@ -35,7 +28,6 @@ RCSID
 
 extern struct vlheader cheader;
 struct vlheader xheader;
-extern struct ubik_dbase *VL_dbase;
 extern afs_uint32 HostAddress[];
 extern int maxnservers;
 struct extentaddr extentaddr;
@@ -608,7 +600,7 @@ FreeBlock(trans, blockindex)
 afs_int32
 FindByID(trans, volid, voltype, tentry, error)
      struct ubik_trans *trans;
-     afs_int32 volid;
+     afs_uint32 volid;
      afs_int32 voltype;
      struct nvlentry *tentry;
      afs_int32 *error;
