@@ -18,7 +18,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/vol/vol-info.c,v 1.22.4.3 2008/11/08 15:58:18 shadow Exp $");
+    ("$Header: /cvs/openafs/src/vol/vol-info.c,v 1.22.4.5 2009/03/23 18:19:07 shadow Exp $");
 
 #include <ctype.h>
 #include <errno.h>
@@ -50,7 +50,8 @@ RCSID
 #include "viceinode.h"
 #include "volinodes.h"
 #include <afs/afssyscalls.h>
-
+#include <afs/afsutil.h>
+    
 #ifdef _AIX
 #include <time.h>
 #endif
@@ -106,7 +107,7 @@ date(time_t date)
 {
 #define MAX_DATE_RESULT	100
     static char results[8][MAX_DATE_RESULT];
-    static next;
+    static int next;
     struct tm *tm = localtime(&date);
     char buf[32];
 
@@ -221,7 +222,7 @@ handleit(struct cmd_syndesc *as, void *arock)
 {
     register struct cmd_item *ti;
     int err = 0;
-    int volumeId = 0;
+    afs_uint32 volumeId = 0;
     char *partName = 0;
     struct DiskPartition64 *partP = NULL;
 
@@ -322,7 +323,7 @@ handleit(struct cmd_syndesc *as, void *arock)
 	    }
 	}
 	(void)afs_snprintf(name1, sizeof name1, VFORMAT,
-			   (unsigned long)volumeId);
+			   afs_cast_uint32(volumeId));
 	if (dsizeOnly && !saveinodes)
 	    printf
 		("Volume-Id\t  Volsize  Auxsize Inodesize  AVolsize SizeDiff                (VolName)\n");
@@ -334,7 +335,7 @@ handleit(struct cmd_syndesc *as, void *arock)
 #ifdef AFS_NT40_ENV
 #include <direct.h>
 struct DiskPartition64 *
-FindCurrentPartition()
+FindCurrentPartition(void)
 {
     int dr = _getdrive();
     struct DiskPartition64 *dp;
@@ -351,7 +352,7 @@ FindCurrentPartition()
 }
 #else
 struct DiskPartition64 *
-FindCurrentPartition()
+FindCurrentPartition(void)
 {
     char partName[1024];
     char tmp = '\0';
