@@ -18,7 +18,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/xstat/xstat_fs.c,v 1.10.2.3 2008/03/10 22:32:37 shadow Exp $");
+    ("$Header: /cvs/openafs/src/xstat/xstat_fs.c,v 1.10.2.4 2009/03/20 17:10:19 jaltman Exp $");
 
 #include "xstat_fs.h"		/*Interface for this module */
 #include <lwp.h>		/*Lightweight process package */
@@ -303,12 +303,12 @@ xstat_fs_LWP(void *unused)
 
 		    if (xstat_fs_debug) {
 			printf
-			    ("%s: Calling RXAFS_GetXStats, conn=0x%x, clientVersionNumber=%d, collectionNumber=%d, srvVersionNumberP=0x%x, timeP=0x%x, dataP=0x%x\n",
+			    ("%s: Calling RXAFS_GetXStats, conn=0x%" AFS_PTR_FMT ", clientVersionNumber=%d, collectionNumber=%d, srvVersionNumberP=0x%" AFS_PTR_FMT ", timeP=0x%" AFS_PTR_FMT ", dataP=0x%" AFS_PTR_FMT "\n",
 			     rn, curr_conn->rxconn, clientVersionNumber,
 			     *currCollIDP, &srvVersionNumber,
 			     &(xstat_fs_Results.probeTime),
 			     &(xstat_fs_Results.data));
-			printf("%s: [bufflen=%d, buffer at 0x%x]\n", rn,
+			printf("%s: [bufflen=%d, buffer at 0x%" AFS_PTR_FMT "]\n", rn,
 			       xstat_fs_Results.data.AFS_CollData_len,
 			       xstat_fs_Results.data.AFS_CollData_val);
 		    }
@@ -360,7 +360,7 @@ xstat_fs_LWP(void *unused)
 	     * that we've finished our collection round.
 	     */
 	    if (xstat_fs_debug)
-		printf("[%s] Signalling main process at 0x%x\n", rn,
+		printf("[%s] Signalling main process at 0x%" AFS_PTR_FMT "\n", rn,
 		       &terminationEvent);
 	    oneShotCode = LWP_SignalProcess(&terminationEvent);
 	    if (oneShotCode)
@@ -636,7 +636,7 @@ xstat_fs_Init(int a_numServers, struct sockaddr_in *a_socketArray,
 	    conn_err = 1;
 	}
 	if (xstat_fs_debug)
-	    printf("[%s] New connection at 0x%lx\n", rn, curr_conn->rxconn);
+	    printf("[%s] New connection at 0x%" AFS_PTR_FMT "\n", rn, curr_conn->rxconn);
 
 	/*
 	 * Bump the current xstat_fs connection to set up.
@@ -690,7 +690,7 @@ xstat_fs_Init(int a_numServers, struct sockaddr_in *a_socketArray,
 	return (code);
     }
     if (xstat_fs_debug)
-	printf("[%s] Probe LWP process structure located at 0x%x\n", rn,
+	printf("[%s] Probe LWP process structure located at 0x%" AFS_PTR_FMT "\n", rn,
 	       probeLWP_ID);
 
     /*
